@@ -14,12 +14,14 @@ from .config_entry import ConfigurationEntry as CE
 
 
 _l = logging.getLogger(__name__)
-color_re = re.compile('[0-9a-fA-F]+')
+color_re = re.compile("[0-9a-fA-F]+")
+
 
 class UninterpretedCE(CE):
     """
     A config entry which has not been parsed because no type was available for it.
     """
+
     def __init__(self, name, value, default_value=None):
         super().__init__(name, UninterpretedCE, value, default_value=default_value)
 
@@ -36,18 +38,16 @@ def tomltype2pytype(v, ty: Optional[Type]) -> Any:
     elif ty is list:
         if not isinstance(v, tomlkit.items.Array):
             raise TypeError()
-        return [ tomltype2pytype(v_, None) for v_ in v.value ]
+        return [tomltype2pytype(v_, None) for v_ in v.value]
     return str(v) if isinstance(v, tomlkit.items.String) else v.unwrap()
 
 
 def color_parser(config_option, value) -> Optional[QColor]:
-    if not isinstance(value, str) \
-       or not color_re.match(value) \
-       or len(value) not in (3, 6, 8, 12):
-        _l.error('Failed to parse value %r as rgb color for option %s', value, config_option)
+    if not isinstance(value, str) or not color_re.match(value) or len(value) not in (3, 6, 8, 12):
+        _l.error("Failed to parse value %r as rgb color for option %s", value, config_option)
         return None
 
-    return QColor('#' + value)
+    return QColor("#" + value)
 
 
 def color_serializer(config_option, value: QColor) -> str:
@@ -55,29 +55,30 @@ def color_serializer(config_option, value: QColor) -> str:
         _l.error("Failed to serialize value %r as rgb color for option %s", value, config_option)
         return None
 
-    return f'{value.alpha():02x}{value.red():02x}{value.green():02x}{value.blue():02x}'
+    return f"{value.alpha():02x}{value.red():02x}{value.green():02x}{value.blue():02x}"
 
 
 def font_parser(config_option, value) -> Optional[QFont]:
-    if not isinstance(value, str) or 'px ' not in value:
-        _l.error('Failed to parse value %r as font for option %s', value, config_option)
+    if not isinstance(value, str) or "px " not in value:
+        _l.error("Failed to parse value %r as font for option %s", value, config_option)
         return None
 
-    parts = value.split('px ', 1)
+    parts = value.split("px ", 1)
     try:
         size = int(parts[0])
     except ValueError:
-        _l.error('Failed to parse value %r as font for option %s', value, config_option)
+        _l.error("Failed to parse value %r as font for option %s", value, config_option)
         return None
 
     return QFont(parts[1], size)
 
+
 def font_serializer(config_option, value: QFont) -> str:
     if not isinstance(value, QFont):
         _l.error("Failed to serialize value %r as font for option %s", value, config_option)
         return None
 
-    return f'{value.pointSize()}px {value.family()}'
+    return f"{value.pointSize()}px {value.family()}"
 
 
 def bool_parser(config_option, value) -> bool:
@@ -107,151 +108,150 @@ data_serializers = {
 
 # CE(name, type, default_value)
 ENTRIES = [
-    CE('ui_default_font', QFont, None),
-    CE('tabular_view_font', QFont, None),
-    CE('disasm_font', QFont, QFont("DejaVu Sans Mono", 10)),
-    CE('symexec_font', QFont, QFont("DejaVu Sans Mono", 10)),
-    CE('code_font', QFont, QFont("Source Code Pro", 10)),
-
-    CE('theme_name', str, "Light"),
-    CE('disasm_view_minimap_viewport_color', QColor, QColor(0xFF, 0x00, 0x00)),
-    CE('disasm_view_operand_color', QColor, QColor(0x00, 0x00, 0x80)),
-    CE('disasm_view_operand_constant_color', QColor, QColor(0x00, 0x00, 0x80)),
-    CE('disasm_view_variable_label_color', QColor, QColor(0x00, 0x80, 0x00)),
-    CE('disasm_view_operand_highlight_color', QColor, QColor(0xfc, 0xef, 0x00)),
-    CE('disasm_view_operand_select_color', QColor, QColor(0xff, 0xff, 0x00)),
-    CE('disasm_view_function_color', QColor, QColor(0x00, 0x00, 0xff)),
-    CE('disasm_view_ir_default_color', QColor, QColor(0x80, 0x80, 0x80)),
-    CE('disasm_view_label_color', QColor, QColor(0x00, 0x00, 0xff)),
-    CE('disasm_view_label_highlight_color', QColor, QColor(0xf0, 0xf0, 0xbf)),
-    CE('disasm_view_target_addr_color', QColor, QColor(0x00, 0x00, 0xff)),
-    CE('disasm_view_antitarget_addr_color', QColor, QColor(0xff, 0x00, 0x00)),
-    CE('disasm_view_node_shadow_color', QColor, QColor(0x00, 0x00, 0x00, 0x00)),
-    CE('disasm_view_node_background_color', QColor, QColor(0xfa, 0xfa, 0xfa)),
-    CE('disasm_view_node_zoomed_out_background_color', QColor, QColor(0xda, 0xda, 0xda)),
-    CE('disasm_view_node_border_color', QColor, QColor(0xf0, 0xf0, 0xf0)),
-    CE('disasm_view_node_instruction_selected_background_color', QColor, QColor(0xb8, 0xc3, 0xd6)),
-    CE('disasm_view_node_address_color', QColor, QColor(0x00, 0x00, 0x00)),
-    CE('disasm_view_node_mnemonic_color', QColor, QColor(0x00, 0x00, 0x80)),
-    CE('disasm_view_node_rounding', int, 0),
-    CE('disasm_view_selected_node_border_color', QColor, QColor(0x6b, 0x71, 0x7c)),
-    CE('disasm_view_printable_byte_color', QColor, QColor(0x00, 0x80, 0x40)),
-    CE('disasm_view_printable_character_color', QColor, QColor(0x00, 0x80, 0x40)),
-    CE('disasm_view_unprintable_byte_color', QColor, QColor(0x80, 0x40, 0x00)),
-    CE('disasm_view_unprintable_character_color', QColor, QColor(0x80, 0x40, 0x00)),
-    CE('disasm_view_unknown_byte_color', QColor, QColor(0xf0, 0x00, 0x00)),
-    CE('disasm_view_unknown_character_color', QColor, QColor(0xf0, 0x00, 0x00)),
-    CE('disasm_view_back_edge_color', QColor, QColor(0xf9, 0xd5, 0x77)),
-    CE('disasm_view_true_edge_color', QColor, QColor(0x79, 0xcc, 0xcd)),
-    CE('disasm_view_false_edge_color', QColor, QColor(0xf1, 0x66, 0x64)),
-    CE('disasm_view_direct_jump_edge_color', QColor, QColor(0x56, 0x5a, 0x5c)),
-    CE('disasm_view_exception_edge_color', QColor, QColor(0xf9, 0x91, 0x0a)),
-    CE('hex_view_selection_color', QColor, QColor(0xFF, 0x00, 0x00)),
-    CE('hex_view_selection_alt_color', QColor, QColor(0xA0, 0xA0, 0xA4)),
-    CE('hex_view_data_color', QColor, QColor(0x00, 0x00, 0xFF)),
-    CE('hex_view_string_color', QColor, QColor(0x00, 0xFF, 0xFF)),
-    CE('hex_view_instruction_color', QColor, QColor(0xFF, 0x00, 0xFF)),
-    CE('function_table_color', QColor, QColor(0x00, 0x00, 0x00)),
-    CE('function_table_syscall_color', QColor, QColor(0x00, 0x00, 0x80)),
-    CE('function_table_plt_color', QColor, QColor(0x00, 0x80, 0x00)),
-    CE('function_table_simprocedure_color', QColor, QColor(0x80, 0x00, 0x00)),
-    CE('function_table_alignment_color', QColor, QColor(0x80, 0x00, 0x80)),
-    CE('function_table_signature_bg_color', QColor, QColor(0xaa, 0xff, 0xff)),
-    CE('palette_window', QColor, QColor(0xef, 0xef, 0xef, 0xff)),
-    CE('palette_windowtext', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
-    CE('palette_base', QColor, QColor(0xff, 0xff, 0xff, 0xff)),
-    CE('palette_alternatebase', QColor, QColor(0xf7, 0xf7, 0xf7, 0xff)),
-    CE('palette_tooltipbase', QColor, QColor(0xff, 0xff, 0xdc, 0xff)),
-    CE('palette_tooltiptext', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
-    CE('palette_placeholdertext', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
-    CE('palette_text', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
-    CE('palette_button', QColor, QColor(0xef, 0xef, 0xef, 0xff)),
-    CE('palette_buttontext', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
-    CE('palette_brighttext', QColor, QColor(0xff, 0xff, 0xff, 0xff)),
-    CE('palette_highlight', QColor, QColor(0x30, 0x8c, 0xc6, 0xff)),
-    CE('palette_highlightedtext', QColor, QColor(0xff, 0xff, 0xff, 0xff)),
-    CE('palette_disabled_text', QColor, QColor(0xbe, 0xbe, 0xbe, 0xff)),
-    CE('palette_disabled_buttontext', QColor, QColor(0xbe, 0xbe, 0xbe, 0xff)),
-    CE('palette_disabled_windowtext', QColor, QColor(0xbe, 0xbe, 0xbe, 0xff)),
-    CE('palette_light', QColor, QColor(0xff, 0xff, 0xff, 0xff)),
-    CE('palette_midlight', QColor, QColor(0xca, 0xca, 0xca, 0xff)),
-    CE('palette_dark', QColor, QColor(0x9f, 0x9f, 0x9f, 0xff)),
-    CE('palette_mid', QColor, QColor(0xb8, 0xb8, 0xb8, 0xff)),
-    CE('palette_shadow', QColor, QColor(0x76, 0x76, 0x76, 0xff)),
-    CE('palette_link', QColor, QColor(0x00, 0x00, 0xff, 0xff)),
-    CE('palette_linkvisited', QColor, QColor(0xff, 0x00, 0xff, 0xff)),
-    CE('pseudocode_comment_color', QColor, QColor(0x00, 0x80, 0x00, 0xff)),
-    CE('pseudocode_function_color', QColor, QColor(0x00, 0x00, 0xff, 0xff)),
-    CE('pseudocode_quotation_color', QColor, QColor(0x00, 0x80, 0x00, 0xff)),
-    CE('pseudocode_keyword_color', QColor, QColor(0x00, 0x00, 0x80, 0xff)),
-    CE('pseudocode_highlight_color', QColor, QColor(0xff, 0xff, 0x00, 0xff)),
-    CE('proximity_node_background_color', QColor, QColor(0xfa, 0xfa, 0xfa)),
-    CE('proximity_node_selected_background_color', QColor, QColor(0xcc, 0xcc, 0xcc)),
-    CE('proximity_node_border_color', QColor, QColor(0xf0, 0xf0, 0xf0)),
-    CE('proximity_function_node_text_color', QColor, QColor(0xff, 0x00, 0x00)),
-    CE('proximity_string_node_text_color', QColor, QColor(0x00, 0x80, 0x00)),
-    CE('proximity_integer_node_text_color', QColor, QColor(0x00, 0x00, 0x80)),
-    CE('proximity_variable_node_text_color', QColor, QColor(0x00, 0x00, 0x80)),
-    CE('proximity_unknown_node_text_color', QColor, QColor(0x00, 0x00, 0x80)),
-    CE('proximity_call_node_text_color', QColor, QColor(0x00, 0x00, 0xff)),
-    CE('proximity_call_node_text_color_plt', QColor, QColor(0x8b, 0x00, 0x8b)),
-    CE('proximity_call_node_text_color_simproc', QColor, QColor(0x8b, 0x00, 0x8b)),
-
-    CE('log_timestamp_format', str, "%H:%M:%S"),
-
+    CE("ui_default_font", QFont, None),
+    CE("tabular_view_font", QFont, None),
+    CE("disasm_font", QFont, QFont("DejaVu Sans Mono", 10)),
+    CE("symexec_font", QFont, QFont("DejaVu Sans Mono", 10)),
+    CE("code_font", QFont, QFont("Source Code Pro", 10)),
+    CE("theme_name", str, "Light"),
+    CE("disasm_view_minimap_viewport_color", QColor, QColor(0xFF, 0x00, 0x00)),
+    CE("disasm_view_operand_color", QColor, QColor(0x00, 0x00, 0x80)),
+    CE("disasm_view_operand_constant_color", QColor, QColor(0x00, 0x00, 0x80)),
+    CE("disasm_view_variable_label_color", QColor, QColor(0x00, 0x80, 0x00)),
+    CE("disasm_view_operand_highlight_color", QColor, QColor(0xFC, 0xEF, 0x00)),
+    CE("disasm_view_operand_select_color", QColor, QColor(0xFF, 0xFF, 0x00)),
+    CE("disasm_view_function_color", QColor, QColor(0x00, 0x00, 0xFF)),
+    CE("disasm_view_ir_default_color", QColor, QColor(0x80, 0x80, 0x80)),
+    CE("disasm_view_label_color", QColor, QColor(0x00, 0x00, 0xFF)),
+    CE("disasm_view_label_highlight_color", QColor, QColor(0xF0, 0xF0, 0xBF)),
+    CE("disasm_view_target_addr_color", QColor, QColor(0x00, 0x00, 0xFF)),
+    CE("disasm_view_antitarget_addr_color", QColor, QColor(0xFF, 0x00, 0x00)),
+    CE("disasm_view_node_shadow_color", QColor, QColor(0x00, 0x00, 0x00, 0x00)),
+    CE("disasm_view_node_background_color", QColor, QColor(0xFA, 0xFA, 0xFA)),
+    CE("disasm_view_node_zoomed_out_background_color", QColor, QColor(0xDA, 0xDA, 0xDA)),
+    CE("disasm_view_node_border_color", QColor, QColor(0xF0, 0xF0, 0xF0)),
+    CE("disasm_view_node_instruction_selected_background_color", QColor, QColor(0xB8, 0xC3, 0xD6)),
+    CE("disasm_view_node_address_color", QColor, QColor(0x00, 0x00, 0x00)),
+    CE("disasm_view_node_mnemonic_color", QColor, QColor(0x00, 0x00, 0x80)),
+    CE("disasm_view_node_rounding", int, 0),
+    CE("disasm_view_selected_node_border_color", QColor, QColor(0x6B, 0x71, 0x7C)),
+    CE("disasm_view_printable_byte_color", QColor, QColor(0x00, 0x80, 0x40)),
+    CE("disasm_view_printable_character_color", QColor, QColor(0x00, 0x80, 0x40)),
+    CE("disasm_view_unprintable_byte_color", QColor, QColor(0x80, 0x40, 0x00)),
+    CE("disasm_view_unprintable_character_color", QColor, QColor(0x80, 0x40, 0x00)),
+    CE("disasm_view_unknown_byte_color", QColor, QColor(0xF0, 0x00, 0x00)),
+    CE("disasm_view_unknown_character_color", QColor, QColor(0xF0, 0x00, 0x00)),
+    CE("disasm_view_back_edge_color", QColor, QColor(0xF9, 0xD5, 0x77)),
+    CE("disasm_view_true_edge_color", QColor, QColor(0x79, 0xCC, 0xCD)),
+    CE("disasm_view_false_edge_color", QColor, QColor(0xF1, 0x66, 0x64)),
+    CE("disasm_view_direct_jump_edge_color", QColor, QColor(0x56, 0x5A, 0x5C)),
+    CE("disasm_view_exception_edge_color", QColor, QColor(0xF9, 0x91, 0x0A)),
+    CE("hex_view_selection_color", QColor, QColor(0xFF, 0x00, 0x00)),
+    CE("hex_view_selection_alt_color", QColor, QColor(0xA0, 0xA0, 0xA4)),
+    CE("hex_view_data_color", QColor, QColor(0x00, 0x00, 0xFF)),
+    CE("hex_view_string_color", QColor, QColor(0x00, 0xFF, 0xFF)),
+    CE("hex_view_instruction_color", QColor, QColor(0xFF, 0x00, 0xFF)),
+    CE("function_table_color", QColor, QColor(0x00, 0x00, 0x00)),
+    CE("function_table_syscall_color", QColor, QColor(0x00, 0x00, 0x80)),
+    CE("function_table_plt_color", QColor, QColor(0x00, 0x80, 0x00)),
+    CE("function_table_simprocedure_color", QColor, QColor(0x80, 0x00, 0x00)),
+    CE("function_table_alignment_color", QColor, QColor(0x80, 0x00, 0x80)),
+    CE("function_table_signature_bg_color", QColor, QColor(0xAA, 0xFF, 0xFF)),
+    CE("palette_window", QColor, QColor(0xEF, 0xEF, 0xEF, 0xFF)),
+    CE("palette_windowtext", QColor, QColor(0x00, 0x00, 0x00, 0xFF)),
+    CE("palette_base", QColor, QColor(0xFF, 0xFF, 0xFF, 0xFF)),
+    CE("palette_alternatebase", QColor, QColor(0xF7, 0xF7, 0xF7, 0xFF)),
+    CE("palette_tooltipbase", QColor, QColor(0xFF, 0xFF, 0xDC, 0xFF)),
+    CE("palette_tooltiptext", QColor, QColor(0x00, 0x00, 0x00, 0xFF)),
+    CE("palette_placeholdertext", QColor, QColor(0x00, 0x00, 0x00, 0xFF)),
+    CE("palette_text", QColor, QColor(0x00, 0x00, 0x00, 0xFF)),
+    CE("palette_button", QColor, QColor(0xEF, 0xEF, 0xEF, 0xFF)),
+    CE("palette_buttontext", QColor, QColor(0x00, 0x00, 0x00, 0xFF)),
+    CE("palette_brighttext", QColor, QColor(0xFF, 0xFF, 0xFF, 0xFF)),
+    CE("palette_highlight", QColor, QColor(0x30, 0x8C, 0xC6, 0xFF)),
+    CE("palette_highlightedtext", QColor, QColor(0xFF, 0xFF, 0xFF, 0xFF)),
+    CE("palette_disabled_text", QColor, QColor(0xBE, 0xBE, 0xBE, 0xFF)),
+    CE("palette_disabled_buttontext", QColor, QColor(0xBE, 0xBE, 0xBE, 0xFF)),
+    CE("palette_disabled_windowtext", QColor, QColor(0xBE, 0xBE, 0xBE, 0xFF)),
+    CE("palette_light", QColor, QColor(0xFF, 0xFF, 0xFF, 0xFF)),
+    CE("palette_midlight", QColor, QColor(0xCA, 0xCA, 0xCA, 0xFF)),
+    CE("palette_dark", QColor, QColor(0x9F, 0x9F, 0x9F, 0xFF)),
+    CE("palette_mid", QColor, QColor(0xB8, 0xB8, 0xB8, 0xFF)),
+    CE("palette_shadow", QColor, QColor(0x76, 0x76, 0x76, 0xFF)),
+    CE("palette_link", QColor, QColor(0x00, 0x00, 0xFF, 0xFF)),
+    CE("palette_linkvisited", QColor, QColor(0xFF, 0x00, 0xFF, 0xFF)),
+    CE("pseudocode_comment_color", QColor, QColor(0x00, 0x80, 0x00, 0xFF)),
+    CE("pseudocode_function_color", QColor, QColor(0x00, 0x00, 0xFF, 0xFF)),
+    CE("pseudocode_quotation_color", QColor, QColor(0x00, 0x80, 0x00, 0xFF)),
+    CE("pseudocode_keyword_color", QColor, QColor(0x00, 0x00, 0x80, 0xFF)),
+    CE("pseudocode_highlight_color", QColor, QColor(0xFF, 0xFF, 0x00, 0xFF)),
+    CE("proximity_node_background_color", QColor, QColor(0xFA, 0xFA, 0xFA)),
+    CE("proximity_node_selected_background_color", QColor, QColor(0xCC, 0xCC, 0xCC)),
+    CE("proximity_node_border_color", QColor, QColor(0xF0, 0xF0, 0xF0)),
+    CE("proximity_function_node_text_color", QColor, QColor(0xFF, 0x00, 0x00)),
+    CE("proximity_string_node_text_color", QColor, QColor(0x00, 0x80, 0x00)),
+    CE("proximity_integer_node_text_color", QColor, QColor(0x00, 0x00, 0x80)),
+    CE("proximity_variable_node_text_color", QColor, QColor(0x00, 0x00, 0x80)),
+    CE("proximity_unknown_node_text_color", QColor, QColor(0x00, 0x00, 0x80)),
+    CE("proximity_call_node_text_color", QColor, QColor(0x00, 0x00, 0xFF)),
+    CE("proximity_call_node_text_color_plt", QColor, QColor(0x8B, 0x00, 0x8B)),
+    CE("proximity_call_node_text_color_simproc", QColor, QColor(0x8B, 0x00, 0x8B)),
+    CE("log_timestamp_format", str, "%X"),
     # FLIRT signatures
-    CE('flirt_signatures_root', str, "./flirt_signatures/"),
-
+    CE("flirt_signatures_root", str, "./flirt_signatures/"),
     # Library documentation
-    CE('library_docs_root', str, "./library_docs/"),
-
+    CE("library_docs_root", str, "./library_docs/"),
     # last-used directory
-    CE('last_used_directory', str, ''),
-
+    CE("last_used_directory", str, ""),
     # feature map
-    CE('feature_map_color_regular_function', QColor, QColor(0x00, 0xa0, 0xe8)),
-    CE('feature_map_color_unknown',          QColor, QColor(0x0a, 0x0a, 0x0a)),
-    CE('feature_map_color_delimiter',        QColor, QColor(0x00, 0x00, 0x00)),
-    CE('feature_map_color_data',             QColor, QColor(0xc0, 0xc0, 0xc0)),
-
+    CE("feature_map_color_regular_function", QColor, QColor(0x00, 0xA0, 0xE8)),
+    CE("feature_map_color_unknown", QColor, QColor(0x0A, 0x0A, 0x0A)),
+    CE("feature_map_color_delimiter", QColor, QColor(0x00, 0x00, 0x00)),
+    CE("feature_map_color_data", QColor, QColor(0xC0, 0xC0, 0xC0)),
     # networking
-    CE('http_proxy', str, ""),
-    CE('https_proxy', str, ""),
-
+    CE("http_proxy", str, ""),
+    CE("https_proxy", str, ""),
     # plugins
-    CE('plugin_search_path', str, '$AM_BUILTIN_PLUGINS:~/.local/share/angr-management/plugins'),
-    CE('enabled_plugins', str, ''),
-
+    CE("plugin_search_path", str, "$AM_BUILTIN_PLUGINS:~/.local/share/angr-management/plugins"),
+    CE("enabled_plugins", str, ""),
     # configurations for individual plugins
     # TOOD: Move them to separate locations
-    CE('plugin_ComponentsPlugin_enabled', bool, False),
-
+    CE("plugin_ComponentsPlugin_enabled", bool, False),
     # VARec
-    CE('varec_endpoint', str, "http://192.168.32.129:5000/varec_joint_small"),
-
+    CE("varec_endpoint", str, "http://192.168.32.129:5000/varec_joint_small"),
     # Daemon
-    CE('use_daemon', bool, False),
-
-    #Tabs
+    CE("use_daemon", bool, False),
+    # Tabs
     CE("enabled_tabs", str, ""),
-
     # Recent
     CE("recent_files", list, []),
 ]
 
 
-class ConfigurationManager: # pylint: disable=assigning-non-slot
+class ConfigurationManager:  # pylint: disable=assigning-non-slot
     """
     Globe Configuration Manager for UI configuration with save/load function
     """
-    __slots__ = ('_entries',
-                 '_disasm_font', '_disasm_font_metrics', '_disasm_font_height',
-                 '_disasm_font_width', '_disasm_font_ascent',
-                 '_symexec_font', '_symexec_font_metrics', '_symexec_font_height',
-                 '_symexec_font_width', '_symexec_font_ascent',
-                 '_code_font', '_code_font_metrics', '_code_font_height',
-                 '_code_font_width', '_code_font_ascent', '_last_used_directory'
-                 )
+
+    __slots__ = (
+        "_entries",
+        "_disasm_font",
+        "_disasm_font_metrics",
+        "_disasm_font_height",
+        "_disasm_font_width",
+        "_disasm_font_ascent",
+        "_symexec_font",
+        "_symexec_font_metrics",
+        "_symexec_font_height",
+        "_symexec_font_width",
+        "_symexec_font_ascent",
+        "_code_font",
+        "_code_font_metrics",
+        "_code_font_height",
+        "_code_font_width",
+        "_code_font_ascent",
+        "_last_used_directory",
+    )
 
     def __init__(self, entries=None):
         self._disasm_font = self._disasm_font_metrics = self._disasm_font_height = None
@@ -262,12 +262,12 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
         self._code_font_width = self._code_font_ascent = self._last_used_directory = None
 
         if entries is None:
-            self._entries = { }
+            self._entries = {}
             self.load_initial_entries(reset=True)
         else:
             self._entries = entries
 
-    def load_initial_entries(self, reset: bool=True):
+    def load_initial_entries(self, reset: bool = True):
         """
         Load configuration entries into self._entries.
 
@@ -288,48 +288,57 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
 
         metrics = QFontMetricsF(real_font)
         height = metrics.height()
-        width = metrics.width('A')
+        width = metrics.width("A")
         ascent = metrics.ascent()
         return real_font, metrics, height, width, ascent
 
     def _disasm_manage_font_cache(self):
-        self._disasm_font, \
-        self._disasm_font_metrics, \
-        self._disasm_font_height, \
-        self._disasm_font_width, \
-        self._disasm_font_ascent = ConfigurationManager._manage_font_cache(
+        (
+            self._disasm_font,
+            self._disasm_font_metrics,
+            self._disasm_font_height,
+            self._disasm_font_width,
+            self._disasm_font_ascent,
+        ) = ConfigurationManager._manage_font_cache(
             self.disasm_font,
             self._disasm_font,
             self._disasm_font_metrics,
             self._disasm_font_height,
             self._disasm_font_width,
-            self._disasm_font_ascent)
+            self._disasm_font_ascent,
+        )
 
     def _symexec_manage_font_cache(self):
-        self._symexec_font, \
-        self._symexec_font_metrics, \
-        self._symexec_font_height, \
-        self._symexec_font_width, \
-        self._symexec_font_ascent = ConfigurationManager._manage_font_cache(
+        (
+            self._symexec_font,
+            self._symexec_font_metrics,
+            self._symexec_font_height,
+            self._symexec_font_width,
+            self._symexec_font_ascent,
+        ) = ConfigurationManager._manage_font_cache(
             self.symexec_font,
             self._symexec_font,
             self._symexec_font_metrics,
             self._symexec_font_height,
             self._symexec_font_width,
-            self._symexec_font_ascent)
+            self._symexec_font_ascent,
+        )
 
     def _code_manage_font_cache(self):
-        self._code_font, \
-        self._code_font_metrics, \
-        self._code_font_height, \
-        self._code_font_width, \
-        self._code_font_ascent = ConfigurationManager._manage_font_cache(
+        (
+            self._code_font,
+            self._code_font_metrics,
+            self._code_font_height,
+            self._code_font_width,
+            self._code_font_ascent,
+        ) = ConfigurationManager._manage_font_cache(
             self.code_font,
             self._code_font,
             self._code_font_metrics,
             self._code_font_height,
             self._code_font_width,
-            self._code_font_ascent)
+            self._code_font_ascent,
+        )
 
     disasm_font: QFont
     symexec_font: QFont
@@ -460,7 +469,7 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
         return list(super().__dir__()) + list(self._entries)
 
     @classmethod
-    def parse(cls, f, ignore_unknown_entries: bool=False):
+    def parse(cls, f, ignore_unknown_entries: bool = False):
         entry_map = {}
         for entry in ENTRIES:
             entry_map[entry.name] = entry.copy()
@@ -471,7 +480,7 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
             for k, v in loaded.items():
                 if k not in entry_map:
                     if ignore_unknown_entries:
-                        _l.warning('Unknown configuration option \'%s\'. Ignoring...', k)
+                        _l.warning("Unknown configuration option '%s'. Ignoring...", k)
                     else:
                         entry_map[k] = UninterpretedCE(k, v)
                     continue
@@ -482,7 +491,7 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
                 if entry.value is None:
                     entry_map[k] = UninterpretedCE(k, v)
         except tomlkit.exceptions.ParseError:
-            _l.error('Failed to parse configuration file: \'%s\'. Continuing with default options...', exc_info=True)
+            _l.error("Failed to parse configuration file: '%s'. Continuing with default options...", exc_info=True)
 
         return cls(entry_map)
 
@@ -496,10 +505,13 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
             try:
                 v = tomltype2pytype(v, ty)
             except TypeError:
-                _l.warning('Value \'%s\' for configuration option \'%s\' has type \'%s\', '
-                           'expected type \'%s\'. Ignoring...',
-                           v, k, type(v), ty,
-                           )
+                _l.warning(
+                    "Value '%s' for configuration option '%s' has type '%s', " "expected type '%s'. Ignoring...",
+                    v,
+                    k,
+                    type(v),
+                    ty,
+                )
                 return None
 
         return v
@@ -521,8 +533,8 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
                     self._entries[entry.name] = entry
 
     @classmethod
-    def parse_file(cls, path: str, ignore_unknown_entries: bool=False):
-        with open(path, 'r', encoding="utf-8") as f:
+    def parse_file(cls, path: str, ignore_unknown_entries: bool = False):
+        with open(path, encoding="utf-8") as f:
             return cls.parse(f, ignore_unknown_entries=ignore_unknown_entries)
 
     def save(self, f):
@@ -535,8 +547,8 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
 
         tomlkit.dump(out, f)
 
-    def save_file(self, path:str):
-        with open(path, 'w', encoding="utf-8") as f:
+    def save_file(self, path: str):
+        with open(path, "w", encoding="utf-8") as f:
             self.save(f)
 
     def attempt_importing_initial_config(self) -> bool:
@@ -554,6 +566,7 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
             initial_config_path = os.path.join(base, "am_initial_config")
             if os.path.isfile(initial_config_path):
                 from . import save_config  # delayed import # pylint: disable=import-outside-toplevel
+
                 # we found it!
                 new_conf = self.__class__.parse_file(initial_config_path, ignore_unknown_entries=False)
                 # copy entries over
@@ -567,14 +580,15 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
                     os.remove(initial_config_path)
                 except (IsADirectoryError, FileNotFoundError):
                     pass
-                except Exception: #pylint: disable=broad-except
-                    QMessageBox.warning(None,
-                                        "Failed to remove the initial configuration file",
-                                        f"angr management imported the initial configuration but failed to remove the"
-                                        f"initial configuration file at {initial_config_path}. Please remove it "
-                                        f"manually. Otherwise your settings will be overwritten next time angr "
-                                        f"management starts.",
-                                        )
+                except Exception:  # pylint: disable=broad-except
+                    QMessageBox.warning(
+                        None,
+                        "Failed to remove the initial configuration file",
+                        f"angr management imported the initial configuration but failed to remove the"
+                        f"initial configuration file at {initial_config_path}. Please remove it "
+                        f"manually. Otherwise your settings will be overwritten next time angr "
+                        f"management starts.",
+                    )
 
                 break
 
@@ -590,7 +604,8 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
     @property
     def has_operation_mango(self) -> bool:
         try:
-            import argument_resolver # pylint:disable=import-outside-toplevel,unused-import
+            import argument_resolver  # pylint:disable=import-outside-toplevel,unused-import
+
             return True
         except ImportError:
             return False
