@@ -5,6 +5,7 @@ class DecompileFunctionJob(Job):
     """
     The job for running the decompiler analysis. You can trigger this by pressing f5 in a function.
     """
+
     def __init__(self, function, on_finish=None, blocking=False, **kwargs):
         self.kwargs = kwargs
         self.function = function
@@ -13,12 +14,12 @@ class DecompileFunctionJob(Job):
     def _run(self, inst):
         decompiler = inst.project.analyses.Decompiler(
             self.function,
-            flavor='pseudocode',
+            flavor="pseudocode",
             variable_kb=inst.pseudocode_variable_kb,
             **self.kwargs,
             progress_callback=self._progress_callback,
         )
         # cache the result
-        inst.kb.structured_code[(self.function.addr, 'pseudocode')] = decompiler.cache
+        inst.kb.structured_code[(self.function.addr, "pseudocode")] = decompiler.cache
 
         inst.workspace.plugins.decompile_callback(self.function)
