@@ -47,7 +47,7 @@ class DependencyAnalysisJob(Job):
         self.func_addr: Optional[int] = func_addr
         self.func_arg_idx: Optional[int] = func_arg_idx
 
-    def _get_sink_and_atom(self, inst: 'Instance'):
+    def _get_sink_and_atom(self, inst: "Instance"):
         if self.func_addr is not None:
             sinks = [func for func in inst.kb.functions.values() if func.addr == self.func_addr]
             if not sinks:
@@ -66,20 +66,19 @@ class DependencyAnalysisJob(Job):
 
             # convert arg into atom
             if isinstance(arg, SimRegArg):
-                atom = Register(inst.project.arch.registers[arg.reg_name][0],
-                                arg.size)
+                atom = Register(inst.project.arch.registers[arg.reg_name][0], arg.size)
                 return sink, atom
             else:
                 raise NotImplementedError()
 
         return None, None
 
-    def _run(self, inst: 'Instance'):
+    def _run(self, inst: "Instance"):
         self._progress_callback(0.0)
         self._perform(inst)
         self._progress_callback(100.0)
 
-    def _perform(self, inst: 'Instance'):
+    def _perform(self, inst: "Instance"):
         if not argument_resolver:
             gui_thread_schedule_async(self._display_import_error)
             return
@@ -90,7 +89,7 @@ class DependencyAnalysisJob(Job):
             # invalid sink setup
             return None
 
-        closures = { }
+        closures = {}
         excluded_functions: Set[int] = set()
         min_depth = 1
         max_depth = 8
@@ -98,28 +97,29 @@ class DependencyAnalysisJob(Job):
 
         for depth in range(min_depth, max_depth):
             base_progress: float = 30.0 + (depth - min_depth) * progress_chunk
-            self._progress_callback(base_progress,
-                                    text="Calculating reaching definitions... depth %d." % depth)
+            self._progress_callback(base_progress, text="Calculating reaching definitions... depth %d." % depth)
             # generate RDA observation points
             observation_points = set()
             for pred in inst.cfg.am_obj.get_predecessors(inst.cfg.am_obj.get_any_node(self.func_addr)):
                 if pred.instruction_addrs:
                     call_inst_addr = pred.instruction_addrs[-1]
-                    observation_point = ('insn', call_inst_addr, OP_BEFORE)
+                    observation_point = ("insn", call_inst_addr, OP_BEFORE)
                     observation_points.add(observation_point)
 
-            for idx, total, dep in self._dependencies(sink, [(atom,SimType())], inst.project.kb, inst.project, depth,
-                                                      excluded_functions, observation_points):
+            for idx, total, dep in self._dependencies(
+                sink, [(atom, SimType())], inst.project.kb, inst.project, depth, excluded_functions, observation_points
+            ):
                 self._progress_callback(
                     base_progress + idx / total * progress_chunk,
-                    text="Computing transitive closures: %d/%d - depth %d" % (idx + 1, total, depth))
+                    text="Computing transitive closures: %d/%d - depth %d" % (idx + 1, total, depth),
+                )
 
                 all_defs = set()
                 # find the instructions that call this function
                 for pred in inst.cfg.am_obj.get_predecessors(inst.cfg.am_obj.get_any_node(self.func_addr)):
                     if pred.instruction_addrs:
                         call_inst_addr = pred.instruction_addrs[-1]
-                        loc = ('insn', call_inst_addr, OP_BEFORE)
+                        loc = ("insn", call_inst_addr, OP_BEFORE)
                         if loc in dep.observed_results:
                             observed_result = dep.observed_results[loc]
                             defs_ = observed_result.get_definitions_from_atoms([atom])
@@ -145,31 +145,49 @@ class DependencyAnalysisJob(Job):
                 if not has_external:
                     # fully resolved - we should exclude this function for future exploration
                     current_function_address = dep.subject.content.current_function_address()
-                    l.info("Exclude function %#x from future slices since the data dependencies are fully resolved.",
-                           current_function_address)
+                    l.info(
+                        "Exclude function %#x from future slices since the data dependencies are fully resolved.",
+                        current_function_address,
+                    )
                     excluded_functions.add(current_function_address)
 
                 closures.update(cc)
 
         # display in the dependencies view
-        gui_thread_schedule_async(self._display_closures, (inst, atom, sink.addr, closures, ))
+        gui_thread_schedule_async(
+            self._display_closures,
+            (
+                inst,
+                atom,
+                sink.addr,
+                closures,
+            ),
+        )
 
         return
 
     @staticmethod
-    def _dependencies(subject, sink_atoms: List[Tuple['Atom',SimType]], kb, project, max_depth: int,
-                      excluded_funtions: Set[int],
-                      observation_points: Set[Tuple]) -> Generator[Tuple[int,int,'ReachingDefinitionsAnalysis'], None, None]:
-        Handler = handler_factory([
-            StdioHandlers,
-            StdlibHandlers,
-            StringHandlers,
-        ])
+    def _dependencies(
+        subject,
+        sink_atoms: List[Tuple["Atom", SimType]],
+        kb,
+        project,
+        max_depth: int,
+        excluded_funtions: Set[int],
+        observation_points: Set[Tuple],
+    ) -> Generator[Tuple[int, int, "ReachingDefinitionsAnalysis"], None, None]:
+        Handler = handler_factory(
+            [
+                StdioHandlers,
+                StdlibHandlers,
+                StringHandlers,
+            ]
+        )
 
         if isinstance(subject, Function):
             sink = subject
         else:
-            raise TypeError('Unsupported type of subject %s.' % type(subject))
+            raise TypeError("Unsupported type of subject %s." % type(subject))
 
         # peek into the callgraph and discover all functions reaching the sink within N layers of calls, which is determined
         # by the depth parameter
@@ -183,25 +201,20 @@ class DependencyAnalysisJob(Job):
             caller_func_addr = trace.current_function_address()
             callers: Set[int] = set(kb.functions.callgraph.predecessors(caller_func_addr))
             # remove the functions that we already came across - essentially bypassing recursive function calls
-            callers = set(addr for addr in callers if addr not in encountered)
+            callers = {addr for addr in callers if addr not in encountered}
             caller_depth = curr_depth + 1
             if caller_depth >= max_depth:
                 # reached the depth limit. add them to potential analysis starts
                 starts |= set(map(lambda caller_addr: trace.step_back(caller_addr, None, caller_func_addr), callers))
             else:
                 # add them to the queue
-                for item in map(lambda caller_addr: (trace.step_back(caller_addr, None, caller_func_addr),
-                                                     caller_depth),
-                                callers
-                                ):
+                for item in map(
+                    lambda caller_addr: (trace.step_back(caller_addr, None, caller_func_addr), caller_depth), callers
+                ):
                     queue.append(item)
             encountered |= callers
 
-        l.info("Discovered %d function starts at call-depth %d for sink %r.",
-               len(starts),
-               max_depth,
-               sink
-               )
+        l.info("Discovered %d function starts at call-depth %d for sink %r.", len(starts), max_depth, sink)
 
         for idx, start in enumerate(starts):
             handler = Handler(project, False, sink_function=sink, sink_atoms=sink_atoms, cfg=kb.cfgs[0])
@@ -212,7 +225,7 @@ class DependencyAnalysisJob(Job):
                     observation_points=observation_points,
                     function_handler=handler,
                     kb=kb,
-                    dep_graph=DepGraph()
+                    dep_graph=DepGraph(),
                 )
             except Exception:  # pylint:disable=broad-except
                 l.warning("Failed to compute dependencies for function %s.", start, exc_info=True)
@@ -233,13 +246,14 @@ class DependencyAnalysisJob(Job):
 
     @staticmethod
     def _display_import_error():
-        QMessageBox.critical(None,
-                             "Import error",
-                             "Failed to import argument_resolver package. Is operation-mango installed?",
-                             )
+        QMessageBox.critical(
+            None,
+            "Import error",
+            "Failed to import argument_resolver package. Is operation-mango installed?",
+        )
 
     @staticmethod
-    def _display_closures(inst, sink_atom: 'Atom', sink_addr: int, closures):
+    def _display_closures(inst, sink_atom: "Atom", sink_addr: int, closures):
         view = inst.workspace.view_manager.first_view_in_category("dependencies")
         if view is None:
             return
