@@ -13,20 +13,26 @@ class VariableRecoveryJob(Job):
     Identify variables and recover calling convention for a specific, or all function if no function is specified.
     """
 
-    def __init__(self, on_finish=None, on_variable_recovered=None, workers: Optional[int]=None,
-                 func_addr: Optional[int]=None, auto_start=False,
-                 **kwargs):
+    def __init__(
+        self,
+        on_finish=None,
+        on_variable_recovered=None,
+        workers: Optional[int] = None,
+        func_addr: Optional[int] = None,
+        auto_start=False,
+        **kwargs,
+    ):
         super().__init__(name="Variable Recovery", on_finish=on_finish)
 
         self.variable_recovery_args = kwargs
         self.on_variable_recovered = on_variable_recovered
         self.workers = workers
         self.ccc = None
-        self.instance: Optional['Instance'] = None
+        self.instance: Optional["Instance"] = None
         self.started = False
         self.auto_start = auto_start
         self.func_addr = func_addr
-        self.func_addrs_to_prioritize = set() if func_addr is None else { func_addr }
+        self.func_addrs_to_prioritize = set() if func_addr is None else {func_addr}
 
         self._last_progress_callback_triggered = None
 
@@ -50,7 +56,7 @@ class VariableRecoveryJob(Job):
         callees = set(self.instance.kb.functions.callgraph.successors(func_addr))
         self.ccc.prioritize_functions({func_addr} | callees)
 
-    def _run(self, inst: 'Instance'):
+    def _run(self, inst: "Instance"):
         self.instance = inst
         self.started = True
 
