@@ -1,4 +1,3 @@
-
 import os
 import sys
 import subprocess
@@ -107,7 +106,7 @@ class AngrUrlScheme:
 
     def _register_url_scheme_linux(self):
 
-        cmd_0 = ["xdg-mime", "default", "angr.desktop", "x-scheme-handler/{url_scheme}".format(url_scheme=self.URL_SCHEME)]
+        cmd_0 = ["xdg-mime", "default", "angr.desktop", f"x-scheme-handler/{self.URL_SCHEME}"]
 
         # test if xdg-mime is available
         retcode = subprocess.call(["xdg-mime"], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
@@ -131,14 +130,12 @@ Type=Application
         angr_desktop_base = os.path.dirname(angr_desktop_path)
         pathlib.Path(angr_desktop_base).mkdir(parents=True, exist_ok=True)
         with open(angr_desktop_path, "w") as f:
-            f.write(
-                angr_desktop.format(app_path=app_path(), url_scheme=self.URL_SCHEME)
-            )
+            f.write(angr_desktop.format(app_path=app_path(), url_scheme=self.URL_SCHEME))
 
         # register the scheme
         retcode = subprocess.call(cmd_0)
         if retcode != 0:
-            raise ValueError("Failed to setup the URL scheme. Command \"%s\" failed." % " ".join(cmd_0))
+            raise ValueError('Failed to setup the URL scheme. Command "%s" failed.' % " ".join(cmd_0))
 
     def _unregister_url_scheme_linux(self):
 
@@ -159,15 +156,18 @@ Type=Application
             return False, None
 
         # xdg-mine query
-        proc = subprocess.Popen(["xdg-mime", "query", "default",
-            "x-scheme-handler/{url_scheme}".format(url_scheme=self.URL_SCHEME)],
-            stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        proc = subprocess.Popen(
+            ["xdg-mime", "query", "default", f"x-scheme-handler/{self.URL_SCHEME}"],
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
         stdout, _ = proc.communicate()
         if not stdout:
             return False, None
 
         # Load Exec=
-        with open(angr_desktop_path, "r") as f:
+        with open(angr_desktop_path) as f:
             data = f.read()
         lines = data.split("\n")
         cmdline = None
