@@ -13,7 +13,7 @@ class AIL2ARM32(BasePlugin):
         super().__init__(workspace)
         self.sp_adjust = sp_adjust
         self.registers_in_use = []
-        self.free_registers = ['r4', 'r5', 'r6', 'r7', 'r8', 'r9', 'r10', 'r11']
+        self.free_registers = ["r4", "r5", "r6", "r7", "r8", "r9", "r10", "r11"]
         self.free_registers.reverse()
 
     def reserve_register(self):
@@ -53,12 +53,12 @@ class AIL2ARM32(BasePlugin):
         bp = self.workspace.main_instance.project.arch.bp_offset
         sptracker = self.workspace.main_instance.project.analyses.StackPointerTracker(
             self.workspace.main_instance.project.kb.functions[function_addr], {sp, bp}
-            )
+        )
         sp_offset = sptracker.offset_after(expr_addr, sp)
         bp_offset = sptracker.offset_after(expr_addr, bp)
-        if sp_offset >= (1<<(32-1)):
+        if sp_offset >= (1 << (32 - 1)):
             sp_offset -= 1 << 32
-        if bp_offset >= (1<<(32-1)):
+        if bp_offset >= (1 << (32 - 1)):
             bp_offset -= 1 << 32
         return bp_offset + offset_from_bp - sp_offset + adjust
 
@@ -79,14 +79,20 @@ class AIL2ARM32(BasePlugin):
         # Complex Expressions
         ###################################################
         ## ldr REG, [CONSTANT]
-        if isinstance(expr, ailment.Expr.Load) and isinstance(expr.addr, ailment.Expr.Const) \
-            and expr.addr.value <= 0xffff:
+        if (
+            isinstance(expr, ailment.Expr.Load)
+            and isinstance(expr.addr, ailment.Expr.Const)
+            and expr.addr.value <= 0xFFFF
+        ):
             dest = self.reserve_register()
             asm += f"{self.opcode_variant('ldr', size=expr.size)} {dest}, [#{hex(expr.addr.value)}]\n"
             return dest, asm, const_pool
         ## add REG, CONSTANT / lsl REG, CONSTANT
-        elif isinstance(expr, ailment.Expr.BinaryOp) and isinstance(expr.operands[1], ailment.Expr.Const) \
-            and expr.operands[1].value <= 0xffff:
+        elif (
+            isinstance(expr, ailment.Expr.BinaryOp)
+            and isinstance(expr.operands[1], ailment.Expr.Const)
+            and expr.operands[1].value <= 0xFFFF
+        ):
             operand0, ret_asm, ret_const_pool = self.assemble_recursive(expr.operands[0], function_addr, expr_addr)
             asm += ret_asm
             const_pool += ret_const_pool
@@ -98,32 +104,47 @@ class AIL2ARM32(BasePlugin):
             self.return_register(operand0)
             return dest, asm, const_pool
         ## ldr REG, [REG, CONSTANT]
-        elif isinstance(expr, ailment.Expr.Load) and isinstance(expr.addr, ailment.Expr.BinaryOp) \
-            and expr.addr.op == "Add" and isinstance(expr.addr.operands[1], ailment.Expr.Const) \
-            and expr.addr.operands[1].value <= 0xffff:
+        elif (
+            isinstance(expr, ailment.Expr.Load)
+            and isinstance(expr.addr, ailment.Expr.BinaryOp)
+            and expr.addr.op == "Add"
+            and isinstance(expr.addr.operands[1], ailment.Expr.Const)
+            and expr.addr.operands[1].value <= 0xFFFF
+        ):
             operand0, ret_asm, ret_const_pool = self.assemble_recursive(expr.addr.operands[0], function_addr, expr_addr)
             asm += ret_asm
             const_pool += ret_const_pool
             dest = self.reserve_register()
-            asm += (f"{self.opcode_variant('ldr', size=expr.size)} {dest}, "
-                    f"[{operand0}, #{hex(expr.addr.operands[1].value)}]\n")
+            asm += (
+                f"{self.opcode_variant('ldr', size=expr.size)} {dest}, "
+                f"[{operand0}, #{hex(expr.addr.operands[1].value)}]\n"
+            )
             self.return_register(operand0)
             return dest, asm, const_pool
         ## ldr REG, [CONSTANT, REG] -> ldr REG, [REG, CONSTANT]
-        elif isinstance(expr, ailment.Expr.Load) and isinstance(expr.addr, ailment.Expr.BinaryOp) \
-            and expr.addr.op == "Add" and isinstance(expr.addr.operands[0], ailment.Expr.Const) \
-            and expr.addr.operands[0].value <= 0xffff:
+        elif (
+            isinstance(expr, ailment.Expr.Load)
+            and isinstance(expr.addr, ailment.Expr.BinaryOp)
+            and expr.addr.op == "Add"
+            and isinstance(expr.addr.operands[0], ailment.Expr.Const)
+            and expr.addr.operands[0].value <= 0xFFFF
+        ):
             operand1, ret_asm, ret_const_pool = self.assemble_recursive(expr.addr.operands[1], function_addr, expr_addr)
             asm += ret_asm
             const_pool += ret_const_pool
             dest = self.reserve_register()
-            asm += (f"{self.opcode_variant('ldr', size=expr.size)} {dest}, "
-                    f"[{operand1}, #{hex(expr.addr.operands[0].value)}]\n")
+            asm += (
+                f"{self.opcode_variant('ldr', size=expr.size)} {dest}, "
+                f"[{operand1}, #{hex(expr.addr.operands[0].value)}]\n"
+            )
             self.return_register(operand1)
             return dest, asm, const_pool
         ## ldr REG, [REG, REG]
-        elif isinstance(expr, ailment.Expr.Load) and isinstance(expr.addr, ailment.Expr.BinaryOp) \
-            and expr.addr.op == "Add":
+        elif (
+            isinstance(expr, ailment.Expr.Load)
+            and isinstance(expr.addr, ailment.Expr.BinaryOp)
+            and expr.addr.op == "Add"
+        ):
             operand0, ret_asm, ret_const_pool = self.assemble_recursive(expr.addr.operands[0], function_addr, expr_addr)
             asm += ret_asm
             const_pool += ret_const_pool
@@ -138,9 +159,11 @@ class AIL2ARM32(BasePlugin):
         ## ldr REG, [STACK_OFFSET]
         elif isinstance(expr, ailment.Expr.Load) and isinstance(expr.addr, ailment.Expr.StackBaseOffset):
             dest = self.reserve_register()
-            asm += (f"{self.opcode_variant('ldr', size=expr.size)} "
-                    f"{dest}, [sp, "
-                    f"{self.bp_offset_to_sp_offset(expr.addr.offset, function_addr, expr_addr, self.sp_adjust)}]\n")
+            asm += (
+                f"{self.opcode_variant('ldr', size=expr.size)} "
+                f"{dest}, [sp, "
+                f"{self.bp_offset_to_sp_offset(expr.addr.offset, function_addr, expr_addr, self.sp_adjust)}]\n"
+            )
             return dest, asm, const_pool
 
         ###################################################
@@ -178,13 +201,15 @@ class AIL2ARM32(BasePlugin):
         ## sp + offset
         elif isinstance(expr, ailment.Expr.StackBaseOffset):
             dest = self.reserve_register()
-            asm += (f"{self.opcode_variant('ldr', size=expr.size)}"
-                    f"{dest}, [sp, "
-                    f"{self.bp_offset_to_sp_offset(expr.addr.offset, function_addr, expr_addr, self.sp_adjust)}]\n")
+            asm += (
+                f"{self.opcode_variant('ldr', size=expr.size)}"
+                f"{dest}, [sp, "
+                f"{self.bp_offset_to_sp_offset(expr.addr.offset, function_addr, expr_addr, self.sp_adjust)}]\n"
+            )
             return dest, asm, const_pool
         ## Constant -> mov REG, #CONSTANT
         elif isinstance(expr, ailment.Expr.Const):
-            if expr.value <= 0xffff: # either < 16 bits, or > 16 bits but can be represented in 16 bits
+            if expr.value <= 0xFFFF:  # either < 16 bits, or > 16 bits but can be represented in 16 bits
                 dest = self.reserve_register()
                 asm += f"mov {dest}, #{hex(expr.value)}\n"
                 return dest, asm, const_pool
