@@ -2,8 +2,20 @@ from uuid import uuid4
 from copy import deepcopy
 import logging
 
-from PySide6.QtWidgets import QWidget, QVBoxLayout, QGraphicsScene, QGraphicsView, QGraphicsItemGroup, QMessageBox, \
-    QTabWidget, QAbstractItemView, QMenu, QTableWidget, QTableWidgetItem, QHeaderView
+from PySide6.QtWidgets import (
+    QWidget,
+    QVBoxLayout,
+    QGraphicsScene,
+    QGraphicsView,
+    QGraphicsItemGroup,
+    QMessageBox,
+    QTabWidget,
+    QAbstractItemView,
+    QMenu,
+    QTableWidget,
+    QTableWidgetItem,
+    QHeaderView,
+)
 from PySide6.QtGui import QPen, QBrush, QLinearGradient, QColor, QPainter, QImage, QFont, QContextMenuEvent
 from PySide6.QtCore import Qt, QPoint
 
@@ -15,14 +27,8 @@ from .multi_poi import MultiPOI
 _l = logging.getLogger(name=__name__)
 
 EMPTY_POI = {
-    'category': '',
-    'output': {
-        'function': None,
-        'bbl': None,
-        'base': None,
-        'bbl_history': None,
-        'diagnose': None
-    }
+    "category": "",
+    "output": {"function": None, "bbl": None, "base": None, "bbl_history": None, "diagnose": None},
 }
 
 
@@ -52,8 +58,7 @@ class QPOIViewer(QWidget):
     CRASH_COLUMN = 1
     CATEGORY_COLUMN = 2
     DIAGNOSE_COLUMN = 3
-    COLUMN_FIELD = ['id', 'bbl', 'category', 'diagnose']
-
+    COLUMN_FIELD = ["id", "bbl", "category", "diagnose"]
 
     def __init__(self, workspace, parent=None, diagnose_handler=None):
         super().__init__(parent=parent)
@@ -73,8 +78,8 @@ class QPOIViewer(QWidget):
         self.traceView = None
         self.traceScene = None
         self.POITraceTab = None
-        self.multiPOITab : QWidget = None
-        self.multiPOIList : QTableWidget = None
+        self.multiPOITab: QWidget = None
+        self.multiPOIList: QTableWidget = None
 
         self.mark = None
         self.curr_position = 0
@@ -119,7 +124,7 @@ class QPOIViewer(QWidget):
 
     def _init_widgets(self):
         _l.debug("QPOI Viewer Initiating")
-        self.tabView = QTabWidget() # QGraphicsView()
+        self.tabView = QTabWidget()  # QGraphicsView()
         self.tabView.setContentsMargins(0, 0, 0, 0)
 
         #
@@ -147,7 +152,7 @@ class QPOIViewer(QWidget):
         multiLayout.setSpacing(0)
         multiLayout.setContentsMargins(0, 0, 0, 0)
 
-        self.multiPOIList = QTableWidget(0, 4) # row, col
+        self.multiPOIList = QTableWidget(0, 4)  # row, col
         self.multiPOIList.setHorizontalHeaderItem(0, QTableWidgetItem("ID"))
         self.multiPOIList.setHorizontalHeaderItem(1, QTableWidgetItem("Crash Point"))
         self.multiPOIList.setHorizontalHeaderItem(2, QTableWidgetItem("Tag"))
@@ -172,7 +177,7 @@ class QPOIViewer(QWidget):
         self.show()
 
     def _reset(self):
-        self.traceScene.clear() #clear items
+        self.traceScene.clear()  # clear items
         self.mark = None
 
         self.legend = None
@@ -199,12 +204,12 @@ class QPOIViewer(QWidget):
         # sanity checks
         if not isinstance(poi, dict):
             return
-        if 'output' not in poi or not isinstance(poi['output'], dict):
+        if "output" not in poi or not isinstance(poi["output"], dict):
             return
-        if 'bbl_history' not in poi['output']:
+        if "bbl_history" not in poi["output"]:
             return
 
-        trace = poi['output']['bbl_history']
+        trace = poi["output"]["bbl_history"]
         if self._selected_poi != poi_id and trace is not None:
             # render the trace
             self.poi_trace.am_obj = TraceStatistics(self.workspace, trace, trace_id=poi_id)
@@ -216,12 +221,12 @@ class QPOIViewer(QWidget):
             self.multi_poi.am_obj.reload_heatmap(poi_id)
 
             # redraw function view
-            view = self.workspace.view_manager.first_view_in_category('functions')
+            view = self.workspace.view_manager.first_view_in_category("functions")
             if view is not None:
                 view.refresh()
 
             # redraw disassembly view
-            view = self.workspace.view_manager.first_view_in_category('disassembly')
+            view = self.workspace.view_manager.first_view_in_category("disassembly")
             if view is not None:
                 view.redraw_current_graph()
 
@@ -239,7 +244,7 @@ class QPOIViewer(QWidget):
                 pass
         if crash_addr is not None:
             # show the crashing address
-            view = self.workspace.view_manager.first_view_in_category('disassembly')
+            view = self.workspace.view_manager.first_view_in_category("disassembly")
             if view is not None:
                 crash_func = self._get_func_from_addr(crash_addr)
                 if crash_func is not None:
@@ -256,13 +261,13 @@ class QPOIViewer(QWidget):
         poi_id = self.multiPOIList.item(row, self.POIID_COLUMN).text()
         content = item.text()
         original_content = self.multi_poi.am_obj.get_content_by_id_column(poi_id, column)
-        _l.debug('updaing %s, content: %s, original: %s', poi_id, content, original_content)
+        _l.debug("updaing %s, content: %s, original: %s", poi_id, content, original_content)
         if not self._is_identical(content, original_content):
             updated_poi = self.multi_poi.update_poi(poi_id, column, content)
             self._diagnose_handler.submit_updated_poi(poi_id, updated_poi)
 
     def _subscribe_add_poi(self):
-        _l.debug('add a poi to multi poi list')
+        _l.debug("add a poi to multi poi list")
         if self.multi_poi.am_none:
             self.multi_poi.am_obj = MultiPOI(self.workspace)
         poi_ids = self.multi_poi.am_obj.get_all_poi_ids()
@@ -272,12 +277,11 @@ class QPOIViewer(QWidget):
         self.show()
 
     def _subscribe_set_trace(self):
-        _l.debug('on set trace in poi trace viewer')
+        _l.debug("on set trace in poi trace viewer")
         self._reset()
         if self.poi_trace.am_none:
             return
-        _l.debug('minheight: %d, count: %d', self.TRACE_FUNC_MINHEIGHT,
-                self.poi_trace.count)
+        _l.debug("minheight: %d, count: %d", self.TRACE_FUNC_MINHEIGHT, self.poi_trace.count)
         if self.poi_trace.count <= 0:
             _l.warning("No valid addresses found in trace to show. Check base address offsets?")
             self.poi_trace.am_obj = None
@@ -307,7 +311,7 @@ class QPOIViewer(QWidget):
 
         self.show()
 
-    def _subscribe_select_ins(self, **kwargs): # pylint: disable=unused-argument
+    def _subscribe_select_ins(self, **kwargs):  # pylint: disable=unused-argument
         if self.poi_trace.am_none:
             return
 
@@ -323,7 +327,7 @@ class QPOIViewer(QWidget):
         if self.selected_ins:
             addr = next(iter(self.selected_ins))
             positions = self.poi_trace.get_positions(addr)
-            if positions: #if addr is in list of positions
+            if positions:  # if addr is in list of positions
                 # handle case where insn was selected from disas view
                 if not self._use_precise_position:
                     self.curr_position = positions[0] - self.poi_trace.count
@@ -331,15 +335,25 @@ class QPOIViewer(QWidget):
                     color = self._get_mark_color(p, self.poi_trace.count)
                     y = self._get_mark_y(p)
 
-                    if p == self.poi_trace.count + self.curr_position: #add thicker line for 'current' mark
-                        self.mark.addToGroup(self.traceScene.addRect(self.MARK_X, y, self.MARK_WIDTH,
-                                                                     self.MARK_HEIGHT*4,
-                                                                     QPen(QColor('black')), QBrush(color)))
+                    if p == self.poi_trace.count + self.curr_position:  # add thicker line for 'current' mark
+                        self.mark.addToGroup(
+                            self.traceScene.addRect(
+                                self.MARK_X,
+                                y,
+                                self.MARK_WIDTH,
+                                self.MARK_HEIGHT * 4,
+                                QPen(QColor("black")),
+                                QBrush(color),
+                            )
+                        )
                     else:
-                        self.mark.addToGroup(self.traceScene.addRect(self.MARK_X, y, self.MARK_WIDTH,
-                                                                     self.MARK_HEIGHT, QPen(color), QBrush(color)))
+                        self.mark.addToGroup(
+                            self.traceScene.addRect(
+                                self.MARK_X, y, self.MARK_WIDTH, self.MARK_HEIGHT, QPen(color), QBrush(color)
+                            )
+                        )
 
-                self.traceScene.update() #force redraw of the traceScene
+                self.traceScene.update()  # force redraw of the traceScene
                 self.scroll_to_position(self.curr_position)
 
     def _get_func_from_addr(self, addr):
@@ -352,26 +366,26 @@ class QPOIViewer(QWidget):
     def _populate_poi_table(self, view, poi_ids):
         view.clearContents()
         view.setRowCount(len(poi_ids))
-        row = 0 #start after label row
+        row = 0  # start after label row
         for poi_id in poi_ids:
             poi = self.multi_poi.am_obj.get_poi_by_id(poi_id)
-            _l.debug('populating poi: %s', poi)
-            category = poi['category']
-            output = poi['output']
-            crash_addr = output['bbl']
+            _l.debug("populating poi: %s", poi)
+            category = poi["category"]
+            output = poi["output"]
+            crash_addr = output["bbl"]
             if crash_addr is not None:
                 crash = hex(crash_addr)
             else:
                 crash = None
-            diagnose = output.get('diagnose')
-            _l.debug('poi_ids: %s', poi_ids)
-            _l.debug('current poi id: %s', poi_id)
+            diagnose = output.get("diagnose")
+            _l.debug("poi_ids: %s", poi_ids)
+            _l.debug("current poi id: %s", poi_id)
             self._set_item(view, row, self.POIID_COLUMN, poi_id, editable=False)
             self._set_item(view, row, self.CRASH_COLUMN, crash, editable=True)
             self._set_item(view, row, self.CATEGORY_COLUMN, category, editable=True)
             self._set_item(view, row, self.DIAGNOSE_COLUMN, diagnose, editable=True)
             row += 1
-            _l.debug('poi_ids: %s', poi_ids)
+            _l.debug("poi_ids: %s", poi_ids)
 
     @staticmethod
     def _set_item(view, row, column, text, editable=True):
@@ -462,8 +476,7 @@ class QPOIViewer(QWidget):
 
     def _get_mark_color(self, i, total):
         relative_gradient_pos = i * 1000 // total
-        return self.legend_img.pixelColor(self.LEGEND_WIDTH // 2,
-                                          relative_gradient_pos)
+        return self.legend_img.pixelColor(self.LEGEND_WIDTH // 2, relative_gradient_pos)
 
     def _get_mark_y(self, i):
         return self.TRACE_FUNC_Y + self.trace_func_unit_height * i
@@ -475,18 +488,18 @@ class QPOIViewer(QWidget):
         for position in self.poi_trace.trace_func:
             func_name = position.func_name
             color = self.poi_trace.get_func_color(func_name)
-            self.trace_func.addToGroup(self.traceScene.addRect(x, y,
-                                                          self.TRACE_FUNC_WIDTH, self.trace_func_unit_height,
-                                                          QPen(color), QBrush(color)))
+            self.trace_func.addToGroup(
+                self.traceScene.addRect(
+                    x, y, self.TRACE_FUNC_WIDTH, self.trace_func_unit_height, QPen(color), QBrush(color)
+                )
+            )
             if show_func_tag is True and func_name != prev_name:
                 tag = self.traceScene.addText(func_name, QFont("Source Code Pro", 7))
-                tag.setPos(x + self.TRACE_FUNC_WIDTH +
-                           self.TAG_SPACING, y -
-                           tag.boundingRect().height() // 2)
+                tag.setPos(x + self.TRACE_FUNC_WIDTH + self.TAG_SPACING, y - tag.boundingRect().height() // 2)
                 self.trace_func.addToGroup(tag)
                 anchor = self.traceScene.addLine(
-                    self.TRACE_FUNC_X + self.TRACE_FUNC_WIDTH, y,
-                    x + self.TRACE_FUNC_WIDTH + self.TAG_SPACING, y)
+                    self.TRACE_FUNC_X + self.TRACE_FUNC_WIDTH, y, x + self.TRACE_FUNC_WIDTH + self.TAG_SPACING, y
+                )
                 self.trace_func.addToGroup(anchor)
                 prev_name = func_name
             y += self.trace_func_unit_height
@@ -504,20 +517,22 @@ class QPOIViewer(QWidget):
     def _show_legend(self):
         pen = QPen(Qt.transparent)
 
-        gradient = self._make_legend_gradient(self.LEGEND_X, self.LEGEND_Y,
-                                   self.LEGEND_X, self.LEGEND_Y + self.legend_height)
+        gradient = self._make_legend_gradient(
+            self.LEGEND_X, self.LEGEND_Y, self.LEGEND_X, self.LEGEND_Y + self.legend_height
+        )
         brush = QBrush(gradient)
-        self.legend = self.traceScene.addRect(self.LEGEND_X, self.LEGEND_Y,
-                                         self.LEGEND_WIDTH, self.legend_height, pen, brush)
+        self.legend = self.traceScene.addRect(
+            self.LEGEND_X, self.LEGEND_Y, self.LEGEND_WIDTH, self.legend_height, pen, brush
+        )
 
         reference_gradient = self._make_legend_gradient(0, 0, self.LEGEND_WIDTH, 1000)
         base_img = QImage(self.LEGEND_WIDTH, 1000, QImage.Format.Format_ARGB32)
         p = QPainter(base_img)
-        p.fillRect(base_img.rect(),reference_gradient)
-        self.legend_img = base_img #reference shade
+        p.fillRect(base_img.rect(), reference_gradient)
+        self.legend_img = base_img  # reference shade
 
     def _set_mark_color(self):
-        _l.debug('trace count: %d', self.poi_trace.count)
+        _l.debug("trace count: %d", self.poi_trace.count)
         for p in range(self.poi_trace.count):
             color = self._get_mark_color(p, self.poi_trace.count)
             self.poi_trace.set_mark_color(p, color)
@@ -525,8 +540,10 @@ class QPOIViewer(QWidget):
     def _at_legend(self, pos):
         x = pos.x()
         y = pos.y()
-        return self.TRACE_FUNC_X + self.LEGEND_X < x < self.traceView.width() and \
-           self.TRACE_FUNC_Y < y < self.TRACE_FUNC_Y + self.legend_height
+        return (
+            self.TRACE_FUNC_X + self.LEGEND_X < x < self.traceView.width()
+            and self.TRACE_FUNC_Y < y < self.TRACE_FUNC_Y + self.legend_height
+        )
 
     def _to_logical_pos(self, pos):
         x_offset = self.traceView.horizontalScrollBar().value()
@@ -552,14 +569,16 @@ class QPOIViewer(QWidget):
     #
 
     def menu_add_empty_poi(self):
-        _l.debug('adding a new empty poi item')
+        _l.debug("adding a new empty poi item")
 
         if self._diagnose_handler.get_image_id() is None:
-            QMessageBox.warning(self.workspace.main_window,
-                                "No CHESS target available",
-                                "No angr project is loaded, or you did not associate the current project with a CHESS "
-                                "target. Please load a binary and associate it with a CHESS target before creating "
-                                "POIs.")
+            QMessageBox.warning(
+                self.workspace.main_window,
+                "No CHESS target available",
+                "No angr project is loaded, or you did not associate the current project with a CHESS "
+                "target. Please load a binary and associate it with a CHESS target before creating "
+                "POIs.",
+            )
             return
 
         poi_id = str(uuid4())
@@ -574,7 +593,7 @@ class QPOIViewer(QWidget):
         items = self.multiPOIList.selectedItems()
         row = items.pop().row()
         poi_id = self.multiPOIList.item(row, 0).text()
-        _l.debug('removing ID %s', poi_id)
+        _l.debug("removing ID %s", poi_id)
         self.multi_poi.remove_poi(poi_id)
         self.multi_poi.am_event()
 
@@ -582,7 +601,7 @@ class QPOIViewer(QWidget):
     def _is_identical(content, original_content):
         if content == original_content:
             return True
-        if content == '' and original_content is None:
+        if content == "" and original_content is None:
             return True
         try:
             if int(content, 16) == int(original_content):
@@ -596,15 +615,16 @@ class QMultiPOITab(QWidget):
     """
     The tab widget for multi POIs
     """
-    def __init__(self, poi_view : QPOIViewer):
+
+    def __init__(self, poi_view: QPOIViewer):
         super().__init__()
         self.POIView = poi_view
 
-    def contextMenuEvent(self, event:QContextMenuEvent):
+    def contextMenuEvent(self, event: QContextMenuEvent):
         menu = QMenu("", self)
-        menu.addAction('Add POI', self.POIView.menu_add_empty_poi)
+        menu.addAction("Add POI", self.POIView.menu_add_empty_poi)
 
-        remove = menu.addAction('Remove', self.POIView.menu_remove_poi)
+        remove = menu.addAction("Remove", self.POIView.menu_remove_poi)
         if len(self.POIView.multiPOIList.selectedItems()) == 0:
             remove.setDisabled(True)
 
@@ -621,7 +641,7 @@ class POIView(BaseView):
     """
 
     def __init__(self, workspace, default_docking_position, diagnose_handler, *args, **kwargs):
-        super().__init__('poi', workspace, default_docking_position, *args, **kwargs)
+        super().__init__("poi", workspace, default_docking_position, *args, **kwargs)
 
         self.base_caption = "Points of interest"
         self._diagnose_handler = diagnose_handler
