@@ -13,7 +13,7 @@ class DependencyViewer(BasePlugin):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self.transitions: Set[Tuple[int,int]] = set()
+        self.transitions: Set[Tuple[int, int]] = set()
         self.covered_blocks = SortedDict()
 
         self.sink_color = Qt.yellow
@@ -26,10 +26,10 @@ class DependencyViewer(BasePlugin):
                 return None
             block_size = self.covered_blocks[block_addr]
             if block_addr <= addr < block_addr + block_size:
-                return QColor(0xa5, 0xd0, 0xf3)
+                return QColor(0xA5, 0xD0, 0xF3)
         return None
 
-    FUNC_COLUMNS = ('Vuln Sink',)
+    FUNC_COLUMNS = ("Vuln Sink",)
 
     def extract_func_column(self, func, idx):
         assert idx == 0
@@ -39,11 +39,11 @@ class DependencyViewer(BasePlugin):
             func_name = normalize_cpp_function_name(func_name)
             if "(" in func_name:
                 # only take function name
-                func_name = func_name[:func_name.index("(")]
+                func_name = func_name[: func_name.index("(")]
 
         vulntype_and_sinks = sink_manager.get_function_sinks(func_name)
         if not vulntype_and_sinks:
-            return 0, ''
+            return 0, ""
 
         vuln_type, sink = vulntype_and_sinks[0]
         return 1, VulnerabilityType.to_string(vuln_type)
