@@ -16,6 +16,7 @@ class ExecutionStatisticsViewer(BasePlugin):
     return the result in build_qblock_annotations callback and show in the disassmbly view by
     fetch_qblock_annotations function.
     """
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.passthrough_counts = defaultdict(int)
@@ -30,18 +31,18 @@ class ExecutionStatisticsViewer(BasePlugin):
         self._init_widgets()
 
     @property
-    def disasm_view(self) -> 'DisassemblyView':
+    def disasm_view(self) -> "DisassemblyView":
         return self.workspace.view_manager.first_view_in_category("disassembly")
 
     @property
-    def symexec_view(self) -> 'SymexecView':
+    def symexec_view(self) -> "SymexecView":
         return self.workspace.view_manager.first_view_in_category("symexec")
 
     def count_passthrough(self, simgr):
         """Prior to stepping the active states, increment the passthrough count on the basic block(s) that will be
         executed next."""
         if self.bb_addrs is None:
-            self.bb_addrs = set(b.addr for b in self.instance.cfg.nodes())
+            self.bb_addrs = {b.addr for b in self.instance.cfg.nodes()}
         for s in simgr.active:
             for i_addr in s.block().instruction_addrs:
                 if i_addr in self.bb_addrs:
@@ -70,7 +71,7 @@ class ExecutionStatisticsViewer(BasePlugin):
             if s.history.jumpkind.startswith("Ijk_Sys"):
                 self.addr_to_active_states[s.history.jump_source].append(s)
 
-    def _on_simgr_selected(self, *args, src=None, **kwargs): #pylint: disable=unused-argument
+    def _on_simgr_selected(self, *args, src=None, **kwargs):  # pylint: disable=unused-argument
         """Listener for when a new simgr is selected in the symexec view"""
         if src in ["clicked", "from above"]:
             # The "from above" event is emitted when you create a new simgr via right click menu in disasm view
