@@ -41,17 +41,18 @@ class PluginManager:
     tied to the user's settings related to loading paths and activation. Presently this is split between MainWindow (the
     first-boot autoload part) and the LoadPlugins dialog (the extra loading and tweaking activation)
     """
-    def __init__(self, workspace: Optional['Workspace']):
+
+    def __init__(self, workspace: Optional["Workspace"]):
         self.workspace = workspace
         # should one or both of these be ObjectContainers? I think no since we should be synchronizing on models, not
         # views/controllers. not super clear... that's not a hard and fast rule
-        self.loaded_plugins: Dict[str,PluginDescription] = { }
-        self.active_plugins: Dict[str,BasePlugin] = { }
+        self.loaded_plugins: Dict[str, PluginDescription] = {}
+        self.active_plugins: Dict[str, BasePlugin] = {}
 
     def discover_and_initialize_plugins(self):
-        os.environ['AM_BUILTIN_PLUGINS'] = os.path.dirname(__file__)
-        enabled_plugins = [ plugin_.strip() for plugin_ in Conf.enabled_plugins.split(',') if plugin_.strip() ]
-        for search_dir in Conf.plugin_search_path.split(':'):
+        os.environ["AM_BUILTIN_PLUGINS"] = os.path.dirname(__file__)
+        enabled_plugins = [plugin_.strip() for plugin_ in Conf.enabled_plugins.split(",") if plugin_.strip()]
+        for search_dir in Conf.plugin_search_path.split(":"):
             search_dir = os.path.expanduser(search_dir)
             search_dir = os.path.expandvars(search_dir)
 
@@ -59,21 +60,27 @@ class PluginManager:
             dir_and_descs = load_plugin_descriptions_from_dir(search_dir)
             for _, desc in dir_and_descs:
                 if desc.shortname in self.loaded_plugins:
-                    l.warning("Plugin shortname conflict: %s and %s have the same shortname %s.",
-                              self.loaded_plugins[desc.shortname].plugin_file_path,
-                              desc.plugin_file_path,
-                              desc.shortname,
-                              )
+                    l.warning(
+                        "Plugin shortname conflict: %s and %s have the same shortname %s.",
+                        self.loaded_plugins[desc.shortname].plugin_file_path,
+                        desc.plugin_file_path,
+                        desc.shortname,
+                    )
                     continue
                 self.loaded_plugins[desc.shortname] = desc
 
             # activate all enabled plugins
-            for _, desc in self.loaded_plugins.items():
+            for plugin_name, desc in self.loaded_plugins.items():
+                # don't reactivate already active plugins
+                if plugin_name in self.active_plugins:
+                    continue
+
                 plugin_conf_key = f"plugin_{desc.name}_enabled"
 
                 # see if the plugin is enabled or not
-                if (any((plugin in desc.name or plugin.lower() in desc.shortname.lower()) for plugin in enabled_plugins)
-                        and not (hasattr(Conf, plugin_conf_key) and getattr(Conf, plugin_conf_key) is False)):
+                if any(
+                    (plugin in desc.name or plugin.lower() in desc.shortname.lower()) for plugin in enabled_plugins
+                ) and not (hasattr(Conf, plugin_conf_key) and getattr(Conf, plugin_conf_key) is False):
                     # see if we can't load this plugin because headless mode
                     if self.workspace is None and desc.require_workspace:
                         if desc.has_url_actions:
@@ -91,7 +98,7 @@ class PluginManager:
     def verify_plugin_class(self, plugin_cls: Type[BasePlugin]):
         if type(plugin_cls) is not type or not issubclass(plugin_cls, BasePlugin):
             raise TypeError("Cannot load a plugin which is not a BasePlugin subclass")
-        if hasattr(plugin_cls, '_%s__i_hold_this_abstraction_token' % plugin_cls.__name__):
+        if hasattr(plugin_cls, "_%s__i_hold_this_abstraction_token" % plugin_cls.__name__):
             raise TypeError("Cannot load an abstract plugin")
         if plugin_cls.REQUIRE_WORKSPACE and self.workspace is None:
             raise RuntimeError("Cannot load plugin %s in headless mode.")
@@ -122,9 +129,9 @@ class PluginManager:
                 self._register_toolbar_actions(plugin_cls, plugin)
                 self._register_menu_buttons(plugin_cls, plugin)
 
-                for dview in self.workspace.view_manager.views_by_category['disassembly']:
+                for dview in self.workspace.view_manager.views_by_category["disassembly"]:
                     plugin.instrument_disassembly_view(dview)
-                for cview in self.workspace.view_manager.views_by_category['pseudocode']:
+                for cview in self.workspace.view_manager.views_by_category["pseudocode"]:
                     plugin.instrument_code_view(cview)
 
                 self._register_url_actions(plugin_cls, plugin)
@@ -133,15 +140,14 @@ class PluginManager:
             for action in plugin_cls.URL_ACTIONS:
                 register_url_action(action, UrlActionBinaryAware)
 
-        except Exception: #pylint: disable=broad-except
-            l.warning("Plugin %s failed to activate:", plugin_cls.get_display_name(),
-                      exc_info=True)
+        except Exception:  # pylint: disable=broad-except
+            l.warning("Plugin %s failed to activate:", plugin_cls.get_display_name(), exc_info=True)
         else:
             l.info("Activated plugin %s", plugin_cls.get_display_name())
 
     def save_enabled_plugins_to_config(self):
         # pylint: disable=assigning-non-slot
-        Conf.enabled_plugins = ','.join(self.active_plugins.keys())
+        Conf.enabled_plugins = ",".join(self.active_plugins.keys())
         save_config()
 
     def _register_status_bar_widgets(self, plugin: BasePlugin) -> None:
@@ -154,9 +160,12 @@ class PluginManager:
 
     def _register_toolbar_actions(self, plugin_cls: Type[BasePlugin], plugin: BasePlugin) -> None:
         for idx, (icon, tooltip) in enumerate(plugin_cls.TOOLBAR_BUTTONS):
-            action = ToolbarAction(icon, 'plugin %s toolbar %d' % (plugin_cls, idx), tooltip,
-                                   functools.partial(self._dispatch_single, plugin, BasePlugin.handle_click_toolbar,
-                                                     False, idx))
+            action = ToolbarAction(
+                icon,
+                "plugin %s toolbar %d" % (plugin_cls, idx),
+                tooltip,
+                functools.partial(self._dispatch_single, plugin, BasePlugin.handle_click_toolbar, False, idx),
+            )
             plugin.__cached_toolbar_actions.append(action)
             self.workspace._main_window._file_toolbar.add(action)
 
@@ -164,22 +173,17 @@ class PluginManager:
         if plugin_cls.MENU_BUTTONS:
             self.workspace._main_window._plugin_menu.add(MenuSeparator())
         for idx, text in enumerate(plugin_cls.MENU_BUTTONS):
-            action = MenuEntry(text,
-                               functools.partial(self._dispatch_single, plugin, BasePlugin.handle_click_menu, False,
-                                                 idx))
+            action = MenuEntry(
+                text, functools.partial(self._dispatch_single, plugin, BasePlugin.handle_click_menu, False, idx)
+            )
             plugin.__cached_menu_actions.append(action)
             self.workspace._main_window._plugin_menu.add(action)
 
     def _register_url_actions(self, plugin_cls: Type[BasePlugin], plugin: BasePlugin) -> None:
         for action in plugin_cls.URL_ACTIONS:
-            DaemonClient.register_handler(action,
-                                          functools.partial(self._dispatch_single,
-                                                            plugin,
-                                                            BasePlugin.handle_url_action,
-                                                            False,
-                                                            action
-                                                            )
-                                          )
+            DaemonClient.register_handler(
+                action, functools.partial(self._dispatch_single, plugin, BasePlugin.handle_url_action, False, action)
+            )
 
     @staticmethod
     def _register_configuration_entries(plugin_cls: Type[BasePlugin]) -> None:
@@ -195,8 +199,7 @@ class PluginManager:
             Conf.reinterpet()
 
     def get_plugin_instance_by_name(self, shortname: str) -> Optional[BasePlugin]:
-        instances = \
-            [plugin for key, plugin in self.active_plugins.items() if key == shortname]
+        instances = [plugin for key, plugin in self.active_plugins.items() if key == shortname]
         if not instances:
             return None
         if len(instances) > 1:
@@ -235,9 +238,10 @@ class PluginManager:
         try:
             plugin.teardown()
 
-        except Exception: #pylint: disable=broad-except
-            l.warning("Plugin %s errored during removal. The UI may be unstable.", plugin.get_display_name(),
-                      exc_info=True)
+        except Exception:  # pylint: disable=broad-except
+            l.warning(
+                "Plugin %s errored during removal. The UI may be unstable.", plugin.get_display_name(), exc_info=True
+            )
 
         for key in list(self.active_plugins.keys()):
             if self.active_plugins[key] is plugin:
@@ -253,7 +257,7 @@ class PluginManager:
             if custom.__func__ is not func:
                 try:
                     res = custom(*args)
-                except Exception as e: #pylint: disable=broad-except
+                except Exception as e:  # pylint: disable=broad-except
                     self._handle_error(plugin, func, sensitive, e)
                 else:
                     yield res
@@ -264,7 +268,7 @@ class PluginManager:
             if custom.__func__ is not func:
                 try:
                     res = custom(*args)
-                except Exception as e: #pylint: disable=broad-except
+                except Exception as e:  # pylint: disable=broad-except
                     self._handle_error(plugin, func, sensitive, e)
                 else:
                     yield (plugin_shortname, plugin), res
@@ -273,12 +277,12 @@ class PluginManager:
         custom = getattr(plugin, func.__name__)
         try:
             return custom(*args)
-        except Exception as e:  #pylint: disable=broad-except
+        except Exception as e:  # pylint: disable=broad-except
             self._handle_error(plugin, func, sensitive, e)
             return None
 
     def _handle_error(self, plugin, func, sensitive, exc):
-        self.workspace.log("Plugin %s errored during %s" % (plugin.get_display_name(), func.__name__))
+        self.workspace.log(f"Plugin {plugin.get_display_name()} errored during {func.__name__}")
         self.workspace.log(exc)
         if sensitive:
             self.workspace.log("Deactivating %s for error during sensitive operation" % plugin.get_display_name())
@@ -363,7 +367,7 @@ class PluginManager:
         raise IndexError("Not enough columns")
 
     def count_func_columns(self):
-        return sum((len(plugin.FUNC_COLUMNS) for plugin in self.active_plugins.values()))
+        return sum(len(plugin.FUNC_COLUMNS) for plugin in self.active_plugins.values())
 
     def extract_func_column(self, func, idx):
         for plugin in self.active_plugins.values():
@@ -372,15 +376,15 @@ class PluginManager:
             else:
                 try:
                     return plugin.extract_func_column(func, idx)
-                except Exception as e: #pylint: disable=broad-except
+                except Exception as e:  # pylint: disable=broad-except
                     # this should really be a "sensitive" operation but like
                     self.workspace.log(e)
                     self.workspace.log("PLEASE FIX YOUR PLUGIN AHHHHHHHHHHHHHHHHH")
-                    return 0, ''
+                    return 0, ""
         raise IndexError("Not enough columns")
 
     def step_callback(self, simgr):
-        for _ in self._dispatch(BasePlugin.step_callback,True, simgr):
+        for _ in self._dispatch(BasePlugin.step_callback, True, simgr):
             pass
 
     def handle_stack_var_renamed(self, func, offset, old_name, new_name):
