@@ -1,15 +1,24 @@
 from PySide6.QtCore import Qt
-from PySide6.QtWidgets import QTableWidget, QTableWidgetItem, QAbstractItemView, \
-    QMenu, QHeaderView, QDialog, QVBoxLayout
+from PySide6.QtWidgets import (
+    QTableWidget,
+    QTableWidgetItem,
+    QAbstractItemView,
+    QMenu,
+    QHeaderView,
+    QDialog,
+    QVBoxLayout,
+)
+
 
 class EnvTable(QTableWidget):
-    '''
+    """
     Environment Config Table
-    '''
+    """
+
     def __init__(self, items, parent):
         super().__init__(parent)
 
-        header_labels = ['Name', 'Value']
+        header_labels = ["Name", "Value"]
 
         self.setColumnCount(len(header_labels))
         self.setHorizontalHeaderLabels(header_labels)
@@ -26,8 +35,8 @@ class EnvTable(QTableWidget):
     def contextMenuEvent(self, event):
         menu = QMenu("", self)
 
-        menu.addAction('Add a Row', self._action_new_row)
-        menu.addAction('Delete this Row', self._action_delete)
+        menu.addAction("Add a Row", self._action_new_row)
+        menu.addAction("Delete this Row", self._action_delete)
 
         menu.exec_(event.globalPos())
 
@@ -43,14 +52,15 @@ class EnvTable(QTableWidget):
     def get_result(self):
         ret = []
         for i in range(self.rowCount()):
-            ret.append([self.item(i,0).text(), self.item(i,1).text()])
+            ret.append([self.item(i, 0).text(), self.item(i, 1).text()])
         return ret
 
 
 class EnvConfig(QDialog):
-    '''
+    """
     Environment Config Dialog for new state
-    '''
+    """
+
     def __init__(self, env_config=None, instance=None, parent=None):
         super().__init__(parent)
 
@@ -62,10 +72,10 @@ class EnvConfig(QDialog):
 
     def _init_widgets(self):
         layout = QVBoxLayout()
-        self._table = EnvTable(self.env_config,self)
-        layout.addWidget(self._table,0)
+        self._table = EnvTable(self.env_config, self)
+        layout.addWidget(self._table, 0)
         self.setLayout(layout)
 
-    def closeEvent(self, event): #pylint: disable=unused-argument
+    def closeEvent(self, event):  # pylint: disable=unused-argument
         self.env_config = self._table.get_result()
         self.close()
