@@ -5,12 +5,33 @@ import logging
 import archinfo
 from cle import Blob
 
-from PySide6.QtWidgets import QDialog, QVBoxLayout, QHBoxLayout, QLabel, QTabWidget, QCheckBox, QFrame, QGroupBox, \
-    QListWidgetItem, QListWidget, QMessageBox, QLineEdit, QGridLayout, QComboBox, QSizePolicy, QDialogButtonBox
+from PySide6.QtWidgets import (
+    QDialog,
+    QVBoxLayout,
+    QHBoxLayout,
+    QLabel,
+    QTabWidget,
+    QCheckBox,
+    QFrame,
+    QGroupBox,
+    QListWidgetItem,
+    QListWidget,
+    QMessageBox,
+    QLineEdit,
+    QGridLayout,
+    QComboBox,
+    QSizePolicy,
+    QDialogButtonBox,
+)
 from PySide6.QtCore import Qt
 
+try:
+    import pypcode
+except ImportError:
+    pypcode = None
 
-l = logging.getLogger('dialogs.load_binary')
+
+l = logging.getLogger("dialogs.load_binary")
 
 
 class LoadBinaryError(Exception):
@@ -31,19 +52,24 @@ class LoadBinary(QDialog):
         self.file_path = partial_ld.main_object.binary
         self.md5 = None
         self.sha256 = None
-        self.option_widgets = { }
+        self.option_widgets = {}
         self.is_blob = isinstance(partial_ld.main_object, Blob)
         self.arch = partial_ld.main_object.arch
+        self.available_archs = archinfo.all_arches[::]
+
+        if pypcode:
+            for a in pypcode.Arch.enumerate():
+                self.available_archs.extend(a.languages)
 
         # return values
         self.load_options = None
 
-        self.setWindowTitle('Load a new binary')
+        self.setWindowTitle("Load a new binary")
 
         # checksums
-        if hasattr(partial_ld.main_object, 'md5') and partial_ld.main_object.md5 is not None:
+        if hasattr(partial_ld.main_object, "md5") and partial_ld.main_object.md5 is not None:
             self.md5 = binascii.hexlify(partial_ld.main_object.md5).decode("ascii")
-        if hasattr(partial_ld.main_object, 'sha256') and partial_ld.main_object.sha256 is not None:
+        if hasattr(partial_ld.main_object, "sha256") and partial_ld.main_object.sha256 is not None:
             self.sha256 = binascii.hexlify(partial_ld.main_object.sha256).decode("ascii")
 
         self.main_layout = QVBoxLayout()
@@ -63,12 +89,10 @@ class LoadBinary(QDialog):
     #
 
     def _try_loading(self, partial_ld):
-        deps = [ ]
+        deps = []
         processed_objects = set()
         for ident, obj in partial_ld._satisfied_deps.items():
-            if obj is partial_ld._kernel_object or \
-                    obj is partial_ld._extern_object or \
-                    obj is partial_ld.main_object:
+            if obj is partial_ld._kernel_object or obj is partial_ld._extern_object or obj is partial_ld.main_object:
                 continue
             if obj in processed_objects:
                 continue
@@ -77,7 +101,7 @@ class LoadBinary(QDialog):
 
         # dependencies
 
-        dep_list = self.option_widgets['dep_list']  # type: QListWidget
+        dep_list: QListWidget = self.option_widgets["dep_list"]
         for dep in deps:
             dep_item = QListWidgetItem(dep)
             dep_item.setData(Qt.CheckStateRole, Qt.Unchecked)
@@ -91,7 +115,7 @@ class LoadBinary(QDialog):
         # filename
 
         filename_caption = QLabel(self)
-        filename_caption.setText('File name:')
+        filename_caption.setText("File name:")
 
         filename = QLabel(self)
         filename.setText(self.filename)
@@ -103,7 +127,7 @@ class LoadBinary(QDialog):
 
         if self.md5 is not None:
             md5_caption = QLabel(self)
-            md5_caption.setText('MD5:')
+            md5_caption.setText("MD5:")
             md5 = QLineEdit(self)
             md5.setText(self.md5)
             md5.setReadOnly(True)
@@ -115,7 +139,7 @@ class LoadBinary(QDialog):
 
         if self.sha256 is not None:
             sha256_caption = QLabel(self)
-            sha256_caption.setText('SHA256:')
+            sha256_caption.setText("SHA256:")
             sha256 = QLineEdit(self)
             sha256.setText(self.sha256)
             sha256.setReadOnly(True)
@@ -144,57 +168,67 @@ class LoadBinary(QDialog):
     def _init_load_options_tab(self, tab):
         arch_layout = QHBoxLayout()
         arch_caption = QLabel(self)
-        arch_caption.setText('Architecture:')
+        arch_caption.setText("Architecture:")
         arch_caption.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
         arch_layout.addWidget(arch_caption)
         arch_combo = QComboBox(self)
-        for arch in archinfo.all_arches:
-            addendum = ' (P-code Engine)' if hasattr(arch, 'pcode_arch') else ''
-            arch_combo.addItem(f'{arch.bits}b {arch.name} ({arch.memory_endness[-2:]}){addendum}', str(arch))
-        index = arch_combo.findData(str(self.arch))
+
+        index = 0
+        for i, arch in enumerate(self.available_archs):
+            if isinstance(arch, archinfo.Arch):
+                arch_combo.addItem(f"{arch.bits}b {arch.name} ({arch.memory_endness[-2:]})", str(arch))
+                if str(self.arch) == str(arch):
+                    index = i
+            elif pypcode and isinstance(arch, pypcode.ArchLanguage):
+                arch_combo.addItem(f"{arch.id} (P-code Engine)")
+                if self.arch.name == arch.id:
+                    index = i
+            else:
+                assert False, "Unknown architecture type"
+
         arch_combo.setCurrentIndex(index)
         arch_layout.addWidget(arch_combo)
-        self.option_widgets['arch'] = arch_combo
+        self.option_widgets["arch"] = arch_combo
 
         if self.is_blob:
             blob_layout = QGridLayout()
 
             # load address
             base_addr_caption = QLabel(self)
-            base_addr_caption.setText('Base Address:')
+            base_addr_caption.setText("Base Address:")
             blob_layout.addWidget(base_addr_caption, 1, 0)
             base_addr = QLineEdit(self)
-            base_addr.setText('0')
+            base_addr.setText("0")
             blob_layout.addWidget(base_addr, 1, 1)
-            self.option_widgets['base_addr'] = base_addr
+            self.option_widgets["base_addr"] = base_addr
 
             # entry address
             entry_addr_caption = QLabel(self)
-            entry_addr_caption.setText('Entry Address:')
+            entry_addr_caption.setText("Entry Address:")
             blob_layout.addWidget(entry_addr_caption, 2, 0)
             entry_addr = QLineEdit(self)
-            entry_addr.setText('0')
+            entry_addr.setText("0")
             blob_layout.addWidget(entry_addr, 2, 1)
-            self.option_widgets['entry_addr'] = entry_addr
+            self.option_widgets["entry_addr"] = entry_addr
 
         # load debug symbols
         load_debug_info = QCheckBox()
         load_debug_info.setText("Load debug information if available")
         load_debug_info.setChecked(True)
-        self.option_widgets['load_debug_info'] = load_debug_info
+        self.option_widgets["load_debug_info"] = load_debug_info
 
         # auto load libs
 
         auto_load_libs = QCheckBox()
         auto_load_libs.setText("Automatically load all libraries (slow, not recommended)")
         auto_load_libs.setChecked(False)
-        self.option_widgets['auto_load_libs'] = auto_load_libs
+        self.option_widgets["auto_load_libs"] = auto_load_libs
 
         # dependencies list
 
         dep_group = QGroupBox("Dependencies")
         dep_list = QListWidget()
-        self.option_widgets['dep_list'] = dep_list
+        self.option_widgets["dep_list"] = dep_list
 
         sublayout = QVBoxLayout()
         sublayout.addWidget(dep_list)
@@ -206,8 +240,7 @@ class LoadBinary(QDialog):
         layout.addLayout(arch_layout)
         layout.addWidget(load_debug_info)
         layout.addWidget(auto_load_libs)
-        layout.addWidget(dep_group)
-        layout.addStretch(0)
+        layout.addWidget(dep_group, stretch=1)
 
         frame = QFrame(self)
         frame.setLayout(layout)
@@ -219,33 +252,37 @@ class LoadBinary(QDialog):
 
     def _on_ok_clicked(self):
 
-        force_load_libs = [ ]
+        force_load_libs = []
         skip_libs = set()
 
-        dep_list = self.option_widgets['dep_list']  # type: QListWidget
+        dep_list: QListWidget = self.option_widgets["dep_list"]
         for i in range(dep_list.count()):
-            item = dep_list.item(i)  # type: QListWidgetItem
+            item: QListWidgetItem = dep_list.item(i)
             if item.checkState() == Qt.Checked:
                 force_load_libs.append(item.text())
             else:
                 skip_libs.add(item.text())
 
-        self.load_options = { }
-        self.load_options['auto_load_libs'] = self.option_widgets['auto_load_libs'].isChecked()
-        self.load_options['load_debug_info'] = self.option_widgets['load_debug_info'].isChecked()
-        self.load_options['arch'] = archinfo.all_arches[self.option_widgets['arch'].currentIndex()]
+        self.load_options = {}
+        self.load_options["auto_load_libs"] = self.option_widgets["auto_load_libs"].isChecked()
+        self.load_options["load_debug_info"] = self.option_widgets["load_debug_info"].isChecked()
+
+        arch = self.available_archs[self.option_widgets["arch"].currentIndex()]
+        if pypcode and isinstance(arch, pypcode.ArchLanguage):
+            arch = archinfo.ArchPcode(arch.id)
+        self.load_options["arch"] = arch
 
         if self.is_blob:
-            self.load_options['main_opts'] = {
-                'backend': 'blob',
-                'base_addr': int(self.option_widgets['base_addr'].text(), 16),
-                'entry_point': int(self.option_widgets['entry_addr'].text(), 16),
+            self.load_options["main_opts"] = {
+                "backend": "blob",
+                "base_addr": int(self.option_widgets["base_addr"].text(), 16),
+                "entry_point": int(self.option_widgets["entry_addr"].text(), 16),
             }
 
         if force_load_libs:
-            self.load_options['force_load_libs'] = force_load_libs
+            self.load_options["force_load_libs"] = force_load_libs
         if skip_libs:
-            self.load_options['skip_libs'] = skip_libs
+            self.load_options["skip_libs"] = skip_libs
 
         self.close()
 
@@ -253,7 +290,7 @@ class LoadBinary(QDialog):
         self.close()
 
     @staticmethod
-    def run(partial_ld) -> Tuple[Optional[Dict],Optional[Dict],Optional[Dict]]:
+    def run(partial_ld) -> Tuple[Optional[Dict], Optional[Dict], Optional[Dict]]:
         try:
             dialog = LoadBinary(partial_ld)
             dialog.setModal(True)
@@ -264,15 +301,11 @@ class LoadBinary(QDialog):
         return None, None, None
 
     @staticmethod
-    def binary_arch_detect_failed(filename:str, archinfo_msg:str):
+    def binary_arch_detect_failed(filename: str, archinfo_msg: str):
         # TODO: Normalize the path for Windows
-        QMessageBox.warning(None,
-                            "Architecture selection failed",
-                            f"{archinfo_msg} for binary:\n\n{filename}")
+        QMessageBox.warning(None, "Architecture selection failed", f"{archinfo_msg} for binary:\n\n{filename}")
 
     @staticmethod
     def binary_loading_failed(filename):
         # TODO: Normalize the path for Windows
-        QMessageBox.critical(None,
-                             "Failed to load binary",
-                             f"angr failed to load binary {filename}.")
+        QMessageBox.critical(None, "Failed to load binary", f"angr failed to load binary {filename}.")
