@@ -1,9 +1,8 @@
 from .menu import Menu, MenuEntry, MenuSeparator
 
+
 class PluginMenu(Menu):
     def __init__(self, main_window):
         super().__init__("&Plugins", parent=main_window)
 
-        self.entries.extend([
-            MenuEntry('&Manage Plugins...', main_window.open_load_plugins_dialog)
-        ])
+        self.entries.extend([MenuEntry("&Manage Plugins...", main_window.open_load_plugins_dialog)])
