@@ -1,3 +1,5 @@
+from typing import Optional
+
 from PySide6.QtGui import QAction
 from PySide6.QtWidgets import QToolBar
 from PySide6.QtCore import QSize
@@ -21,7 +23,7 @@ class ToolbarAction:
 
 class ToolbarSplitter(ToolbarAction):
     def __init__(self):
-        super(ToolbarSplitter, self).__init__(None, None, None, None)
+        super().__init__(None, None, None, None)
 
 
 class Toolbar:
@@ -30,8 +32,8 @@ class Toolbar:
         self.name = name
 
         self.actions = []
-        self._cached = None  # type: QToolBar
-        self._cached_actions = { }
+        self._cached: Optional[QToolBar] = None
+        self._cached_actions = {}
 
     def qtoolbar(self):
         if self._cached is not None:
