@@ -15,9 +15,9 @@ class LogView(BaseView):
     """
 
     def __init__(self, instance, default_docking_position, *args, **kwargs):
-        super().__init__('log', instance, default_docking_position, *args, **kwargs)
+        super().__init__("log", instance, default_docking_position, *args, **kwargs)
 
-        self.base_caption = 'Log'
+        self.base_caption = "Log"
         self._log_widget: QLogWidget = None
 
         self._init_widgets()
