@@ -13,8 +13,8 @@ class TraceMapView(BaseView):
     """
 
     def __init__(self, instance, default_docking_position, *args, **kwargs):
-        super().__init__('tracemap', instance, default_docking_position, *args, **kwargs)
-        self.base_caption: str = 'Trace Map'
+        super().__init__("tracemap", instance, default_docking_position, *args, **kwargs)
+        self.base_caption: str = "Trace Map"
         self.inner_widget: Optional[QTraceMap] = None
         self._init_widgets()
 
