@@ -1,16 +1,18 @@
-from PySide6.QtWidgets import QComboBox, QHBoxLayout
+from typing import Optional
+
+from PySide6.QtWidgets import QComboBox
 
 from angr.knowledge_plugins import FunctionManager
 
 
 class QFunctionComboBox(QComboBox):
     def __init__(self, show_all_functions=False, selection_callback=None, parent=None):
-        super(QFunctionComboBox, self).__init__(parent)
+        super().__init__(parent)
 
         self._show_all_functions = show_all_functions
         self._selection_callback = selection_callback
 
-        self._function_manager = None  # type: FunctionManager
+        self._function_manager: Optional[FunctionManager] = None
 
         self.currentIndexChanged.connect(self._on_current_index_changed)
 
