@@ -4,8 +4,16 @@ from typing import List, Set, Tuple, Optional, TYPE_CHECKING
 
 from angr.analyses.code_tagging import CodeTags
 
-from PySide6.QtWidgets import (QWidget, QTableView, QAbstractItemView, QHeaderView, QVBoxLayout, QLineEdit, QLabel,
-                               QHBoxLayout)
+from PySide6.QtWidgets import (
+    QWidget,
+    QTableView,
+    QAbstractItemView,
+    QHeaderView,
+    QVBoxLayout,
+    QLineEdit,
+    QLabel,
+    QHBoxLayout,
+)
 from PySide6.QtGui import QBrush, QColor, QCursor
 from PySide6.QtCore import Qt, QAbstractTableModel, SIGNAL, QEvent
 
@@ -25,7 +33,7 @@ class QFunctionTableModel(QAbstractTableModel):
     The table model for QFunctionTable.
     """
 
-    Headers = ['Name', 'Tags', 'Address', 'Binary', 'Size', 'Blocks']
+    Headers = ["Name", "Tags", "Address", "Binary", "Size", "Blocks"]
     NAME_COL = 0
     TAGS_COL = 1
     ADDRESS_COL = 2
@@ -40,6 +48,7 @@ class QFunctionTableModel(QAbstractTableModel):
         self._raw_func_list = func_list
         self.instance = instance
         self._config = Conf
+        self._data_cache = {}
 
     def __len__(self):
         if self._func_list is not None:
@@ -49,7 +58,7 @@ class QFunctionTableModel(QAbstractTableModel):
         return 0
 
     @property
-    def func_list(self) -> List['Function']:
+    def func_list(self) -> List["Function"]:
         if self._func_list is not None:
             return self._func_list
         return self._raw_func_list
@@ -58,6 +67,7 @@ class QFunctionTableModel(QAbstractTableModel):
     def func_list(self, v):
         self._func_list = None
         self._raw_func_list = v
+        self._data_cache.clear()
         self.emit(SIGNAL("layoutChanged()"))
 
     def filter(self, keyword):
@@ -66,20 +76,24 @@ class QFunctionTableModel(QAbstractTableModel):
             self._func_list = None
         else:
             extra_columns = self.instance.workspace.plugins.count_func_columns()
-            self._func_list = [ func for func in self._raw_func_list if
-                                self._func_match_keyword(func, keyword, extra_columns=extra_columns) ]
+            self._func_list = [
+                func
+                for func in self._raw_func_list
+                if self._func_match_keyword(func, keyword, extra_columns=extra_columns)
+            ]
 
+        self._data_cache.clear()
         self.emit(SIGNAL("layoutChanged()"))
 
-    def rowCount(self, *args, **kwargs): # pylint:disable=unused-argument
+    def rowCount(self, *args, **kwargs):  # pylint:disable=unused-argument
         if self.func_list is None:
             return 0
         return len(self.func_list)
 
-    def columnCount(self, *args, **kwargs): # pylint:disable=unused-argument
+    def columnCount(self, *args, **kwargs):  # pylint:disable=unused-argument
         return len(self.Headers) + self.instance.workspace.plugins.count_func_columns()
 
-    def headerData(self, section, orientation, role): # pylint:disable=unused-argument
+    def headerData(self, section, orientation, role):  # pylint:disable=unused-argument
         if role != Qt.DisplayRole:
             return None
 
@@ -101,6 +115,16 @@ class QFunctionTableModel(QAbstractTableModel):
             return None
 
         col = index.column()
+
+        key = (row, col, role)
+        if key in self._data_cache:
+            value = self._data_cache[key]
+        else:
+            value = self._data_uncached(row, col, role)
+            self._data_cache[key] = value
+        return value
+
+    def _data_uncached(self, row, col, role):
         func = self.func_list[row]
 
         if role == Qt.DisplayRole:
@@ -118,7 +142,7 @@ class QFunctionTableModel(QAbstractTableModel):
             else:
                 color = self._config.function_table_color
 
-            #for w in widgets:
+            # for w in widgets:
             #    w.setFlags(w.flags() & ~Qt.ItemIsEditable)
             #    w.setForeground(color)
 
@@ -139,8 +163,9 @@ class QFunctionTableModel(QAbstractTableModel):
 
     def sort(self, column, order):
         self.layoutAboutToBeChanged.emit()
-        self.func_list = sorted(self.func_list, key=lambda f: self._get_column_data(f, column),
-                                reverse=order==Qt.DescendingOrder)
+        self.func_list = sorted(
+            self.func_list, key=lambda f: self._get_column_data(f, column), reverse=order == Qt.DescendingOrder
+        )
         self.layoutChanged.emit()
 
     #
@@ -167,7 +192,7 @@ class QFunctionTableModel(QAbstractTableModel):
         if idx < len(self.Headers):
             data = self._get_column_data(func, idx)
             if idx == self.ADDRESS_COL:
-                return hex(data)
+                return f"{data:x}"
             elif idx == self.TAGS_COL:
                 return self._get_tags_display_string(data)
             else:
@@ -192,7 +217,7 @@ class QFunctionTableModel(QAbstractTableModel):
     def _get_tags_display_string(cls, tags):
         return ", ".join(cls.TAG_STRS.get(t, t) for t in tags)
 
-    def _func_match_keyword(self, func, keyword, extra_columns: int=0):
+    def _func_match_keyword(self, func, keyword, extra_columns: int = 0):
         """
         Check whether the function matches against the given keyword or not.
 
@@ -230,13 +255,14 @@ class QFunctionTableView(QTableView):
     """
     The table view for QFunctionTable.
     """
+
     def __init__(self, parent, instance, selection_callback=None):
         super().__init__(parent)
         self.instance = instance
         self._context_menu = FunctionContextMenu(self)
 
-        self._function_table = parent  # type: QFunctionTable
-        self._selected_func = ObjectContainer(None, 'Currently selected function')
+        self._function_table: QFunctionTable = parent
+        self._selected_func = ObjectContainer(None, "Currently selected function")
         self._selected_func.am_subscribe(selection_callback)
 
         self.horizontalHeader().setVisible(True)
@@ -261,9 +287,9 @@ class QFunctionTableView(QTableView):
         self.horizontalHeader().sortIndicatorChanged.connect(self.sortByColumn)
         self.doubleClicked.connect(self._on_function_selected)
 
-    def refresh(self, added_funcs: Optional[Set[int]]=None, removed_funcs: Optional[Set[int]]=None):
+    def refresh(self, added_funcs: Optional[Set[int]] = None, removed_funcs: Optional[Set[int]] = None):
         if added_funcs:
-            new_funcs = [ ]
+            new_funcs = []
             for addr in added_funcs:
                 try:
                     f_ = self._functions[addr]
@@ -273,7 +299,7 @@ class QFunctionTableView(QTableView):
                     new_funcs.append(f_)
             self._model.func_list += new_funcs
         if removed_funcs:
-            self._model.func_list = [ f_ for f_ in self._model.func_list if f_.addr not in removed_funcs ]
+            self._model.func_list = [f_ for f_ in self._model.func_list if f_.addr not in removed_funcs]
         self.viewport().update()
 
     @property
@@ -298,7 +324,7 @@ class QFunctionTableView(QTableView):
 
     def load_functions(self):
         if not self.show_alignment_functions:
-            self._model.func_list = [ v for v in self._functions.values() if not v.alignment ]
+            self._model.func_list = [v for v in self._functions.values() if not v.alignment]
         else:
             self._model.func_list = list(self._functions.values())
 
@@ -318,7 +344,7 @@ class QFunctionTableView(QTableView):
         self._function_table.show_filter_box(prefix=text)
         return True
 
-    def contextMenuEvent(self, event:'PySide6.QtGui.QContextMenuEvent') -> None: # pylint:disable=unused-argument
+    def contextMenuEvent(self, event: "PySide6.QtGui.QContextMenuEvent") -> None:  # pylint:disable=unused-argument
         rows = self.selectionModel().selectedRows()
         funcs = [self.instance.kb.functions[r.data()] for r in rows]
         self._context_menu.set(funcs).qmenu().popup(QCursor.pos())
@@ -328,6 +354,7 @@ class QFunctionTableFilterBox(QLineEdit):
     """
     The filter box for QFunctionTable.
     """
+
     def __init__(self, parent):
         super().__init__()
 
@@ -335,7 +362,7 @@ class QFunctionTableFilterBox(QLineEdit):
 
         self.installEventFilter(self)
 
-    def eventFilter(self, obj, event): # pylint:disable=unused-argument
+    def eventFilter(self, obj, event):  # pylint:disable=unused-argument
         if event.type() == QEvent.KeyPress:
             if event.key() == Qt.Key_Escape:
                 if self.text():
@@ -358,11 +385,11 @@ class QFunctionTable(QWidget):
         super().__init__(parent)
         self.instance = instance
 
-        self._view: 'FunctionsView' = parent
-        self._table_view = None  # type: QFunctionTableView
-        self._filter_box = None  # type: QFunctionTableFilterBox
-        self._toolbar = None  # type: FunctionTableToolbar
-        self._status_label = None # type: QLabel
+        self._view: "FunctionsView" = parent
+        self._table_view: QFunctionTableView
+        self._filter_box: QFunctionTableFilterBox
+        self._toolbar: FunctionTableToolbar
+        self._status_label: QLabel
 
         self._last_known_func_addrs: Set[int] = set()
 
@@ -373,7 +400,7 @@ class QFunctionTable(QWidget):
         return self._table_view.show_alignment_functions
 
     @property
-    def function_manager(self) -> Optional['FunctionManager']:
+    def function_manager(self) -> Optional["FunctionManager"]:
         if self._table_view is not None:
             return self._table_view.function_manager
         return None
@@ -386,7 +413,7 @@ class QFunctionTable(QWidget):
             self._table_view.function_manager = v
         else:
             raise ValueError("QFunctionTableView is uninitialized.")
-        self._last_known_func_addrs = set(func.addr for func in self._table_view._model.func_list)
+        self._last_known_func_addrs = {func.addr for func in self._table_view._model.func_list}
         self.filter_functions(self._filter_box.text())
         self.update_displayed_function_count()
 
@@ -483,7 +510,7 @@ class QFunctionTable(QWidget):
 
         self.setLayout(layout)
 
-    def _updated_functions(self, function_manager: 'FunctionManager') -> Tuple[Set[int],Set[int]]:
+    def _updated_functions(self, function_manager: "FunctionManager") -> Tuple[Set[int], Set[int]]:
         if len(self._last_known_func_addrs) == len(function_manager.function_addrs_set):
             return set(), set()
         new_func_addrs_set = function_manager.function_addrs_set.copy()
