@@ -1,7 +1,18 @@
 from typing import TYPE_CHECKING
 
-from PySide6.QtWidgets import QFrame, QInputDialog, QLabel, QComboBox, QHBoxLayout, QVBoxLayout, QPushButton, \
-    QCheckBox, QTabWidget, QTreeWidget, QTreeWidgetItem
+from PySide6.QtWidgets import (
+    QFrame,
+    QInputDialog,
+    QLabel,
+    QComboBox,
+    QHBoxLayout,
+    QVBoxLayout,
+    QPushButton,
+    QCheckBox,
+    QTabWidget,
+    QTreeWidget,
+    QTreeWidgetItem,
+)
 from PySide6.QtCore import Qt
 
 from ...data.jobs import SimgrStepJob, SimgrExploreJob
@@ -14,7 +25,7 @@ if TYPE_CHECKING:
 
 
 class QSimulationManagers(QFrame):
-    def __init__(self, instance: 'Instance', simgr, state, parent=None):
+    def __init__(self, instance: "Instance", simgr, state, parent=None):
         """
         :param instance:                The data source for this project
         :param object parent:           The parent widget.
@@ -26,11 +37,11 @@ class QSimulationManagers(QFrame):
         self.simgr = simgr
         self.state = state
 
-        self._simgrs_list = None  # type: QComboBox
-        self._avoids_list = None  # type: QTreeWidget
-        self._finds_list = None  # type: QTreeWidget
-        self._simgr_viewer = None  # type: QSimulationManagerViewer
-        self._oneactive_checkbox = None  # type: QCheckBox
+        self._simgrs_list: QComboBox
+        self._avoids_list: QTreeWidget
+        self._finds_list: QTreeWidget
+        self._simgr_viewer: QSimulationManagerViewer
+        self._oneactive_checkbox: QCheckBox
 
         self._init_widgets()
         self.refresh()
@@ -78,9 +89,9 @@ class QSimulationManagers(QFrame):
     @staticmethod
     def add_address_to_list(qtreelist: QTreeWidget, addr):
         for i in range(qtreelist.topLevelItemCount()):
-            item = qtreelist.topLevelItem(i)  # type: QTreeWidgetItem
+            item: QTreeWidgetItem = qtreelist.topLevelItem(i)
             if int(item.text(0), 16) == addr:
-                return None # deduplicate
+                return None  # deduplicate
 
         item = QTreeWidgetItem(qtreelist)
         item.setText(0, "%#x" % addr)
@@ -106,7 +117,7 @@ class QSimulationManagers(QFrame):
 
         self.setLayout(layout)
 
-    def select_states(self, states: 'List[SimState]'):
+    def select_states(self, states: "List[SimState]"):
         stash_tree_item = self._simgr_viewer.get_stash_tree_item("active")
         states_set = set(states)
         for state_tree_item in stash_tree_item:
@@ -118,7 +129,7 @@ class QSimulationManagers(QFrame):
         # simgrs list
 
         simgrs_label = QLabel(self)
-        simgrs_label.setText('Simulation Manager')
+        simgrs_label.setText("Simulation Manager")
 
         simgrs_list = QComboBox(self)
         self._simgrs_list = simgrs_list
@@ -139,15 +150,15 @@ class QSimulationManagers(QFrame):
 
         # step button
         step_button = QPushButton()
-        step_button.setText('Step actives')
+        step_button.setText("Step actives")
         step_button.released.connect(self._on_step_clicked)
 
         # step until branch
-        step_until_branch_button = QPushButton('Step actives until branch')
+        step_until_branch_button = QPushButton("Step actives until branch")
         step_until_branch_button.released.connect(self._on_step_until_branch_clicked)
 
         # explore button
-        explore_button = QPushButton('Explore')
+        explore_button = QPushButton("Explore")
         explore_button.released.connect(self._on_explore_clicked)
 
         # buttons layout
@@ -169,7 +180,7 @@ class QSimulationManagers(QFrame):
         frame = QFrame()
         frame.setLayout(simgrs_layout)
 
-        tab.addTab(frame, 'General')
+        tab.addTab(frame, "General")
 
     def _init_settings_tab(self, tab):
         oneactive_checkbox = QCheckBox("Keep at most one active path")
@@ -183,7 +194,7 @@ class QSimulationManagers(QFrame):
         frame = QFrame()
         frame.setLayout(settings_layout)
 
-        tab.addTab(frame, 'Settings')
+        tab.addTab(frame, "Settings")
 
     def _init_avoids_tab(self, tab):
         avoids_list = QTreeWidget()
@@ -200,7 +211,7 @@ class QSimulationManagers(QFrame):
         frame = QFrame()
         frame.setLayout(layout)
 
-        tab.addTab(frame, 'Avoids')
+        tab.addTab(frame, "Avoids")
 
         self._avoids_list.itemChanged.connect(self._on_explore_addr_changed)
 
@@ -219,7 +230,7 @@ class QSimulationManagers(QFrame):
         import_button.clicked.connect(lambda: self._import_to_list(self._finds_list))
         layout.addWidget(import_button)
 
-        tab.addTab(frame, 'Finds')
+        tab.addTab(frame, "Finds")
 
         self._finds_list.itemChanged.connect(self._on_explore_addr_changed)
 
@@ -229,16 +240,23 @@ class QSimulationManagers(QFrame):
 
     def _on_step_clicked(self):
         if not self.simgr.am_none:
-            self.instance.add_job(SimgrStepJob.create(self.simgr.am_obj, until_branch=False,
-                step_callback=self.instance.workspace.plugins.step_callback))
+            self.instance.add_job(
+                SimgrStepJob.create(
+                    self.simgr.am_obj, until_branch=False, step_callback=self.instance.workspace.plugins.step_callback
+                )
+            )
 
     def _on_step_until_branch_clicked(self):
         if not self.simgr.am_none:
-            self.instance.add_job(SimgrStepJob.create(self.simgr.am_obj, until_branch=True,
-                step_callback=self.instance.workspace.plugins.step_callback))
+            self.instance.add_job(
+                SimgrStepJob.create(
+                    self.simgr.am_obj, until_branch=True, step_callback=self.instance.workspace.plugins.step_callback
+                )
+            )
 
     def _on_explore_clicked(self):
         if not self.simgr.am_none:
+
             def _step_callback(simgr):
                 self.instance.workspace.plugins.step_callback(simgr)
                 if self._oneactive_checkbox.isChecked():
@@ -246,9 +264,11 @@ class QSimulationManagers(QFrame):
                 gui_thread_schedule(lambda: self.simgr.am_event(src="post_step"))
                 return simgr
 
-            self.instance.add_job(SimgrExploreJob.create(
-                self.simgr, avoid=self.avoid_addrs, find=self.find_addrs, step_callback=_step_callback
-            ))
+            self.instance.add_job(
+                SimgrExploreJob.create(
+                    self.simgr, avoid=self.avoid_addrs, find=self.find_addrs, step_callback=_step_callback
+                )
+            )
 
     def _on_simgr_selection(self):
         i = self._simgrs_list.currentIndex()
@@ -259,25 +279,25 @@ class QSimulationManagers(QFrame):
 
         if simgr != self.simgr.am_obj:
             self.simgr.am_obj = simgr
-            self.simgr.am_event(src='clicked')
+            self.simgr.am_event(src="clicked")
 
     def _on_state_selection(self):
         state = self._simgr_viewer.current_state()
         if state != self.state:
             self.state.am_obj = state
-            self.state.am_event(src='clicked')
+            self.state.am_event(src="clicked")
 
     def _watch_simgr(self, **kwargs):
-        if kwargs.get('src') in ('clicked', 'filter_actives', "post_step"):
+        if kwargs.get("src") in ("clicked", "filter_actives", "post_step"):
             return
-        elif kwargs.get('src') == 'job_done' and kwargs.get('job') == 'step':
+        elif kwargs.get("src") == "job_done" and kwargs.get("job") == "step":
             self._filter_actives(self.simgr)
         else:
             idx = self._simgrs_list.findText(self.simgr.am_obj.am_name)
             self._simgrs_list.setCurrentIndex(idx)
 
     def _watch_state(self, **kwargs):
-        if kwargs.get('src') == 'clicked':
+        if kwargs.get("src") == "clicked":
             return
 
         self._simgr_viewer.select_state(self.state.am_obj)
@@ -285,14 +305,14 @@ class QSimulationManagers(QFrame):
     def _watch_simgrs(self, **kwargs):  # pylint: disable=unused-argument
         self.refresh()
 
-    def _on_explore_addr_changed(self, item: QTreeWidgetItem): #pylint: disable=unused-argument
+    def _on_explore_addr_changed(self, item: QTreeWidgetItem):  # pylint: disable=unused-argument
         """Refresh the disassembly view when an address in the 'avoids' or 'finds' tab is toggled. Ensures that
         annotations next to instructions are updated."""
         view_manager = self.instance.workspace.view_manager
-        if len(view_manager.views_by_category['disassembly']) == 1:
-            view = view_manager.first_view_in_category('disassembly')
+        if len(view_manager.views_by_category["disassembly"]) == 1:
+            view = view_manager.first_view_in_category("disassembly")
         else:
-            view = view_manager.current_view_in_category('disassembly')
+            view = view_manager.current_view_in_category("disassembly")
         if view is not None:
             view.refresh()
 
@@ -307,13 +327,12 @@ class QSimulationManagers(QFrame):
             return False
 
         stashed = simgr.active[1:]
-        simgr.stashes['stashed'].extend(stashed)
-        simgr.stashes['active'] = simgr.active[:1]
+        simgr.stashes["stashed"].extend(stashed)
+        simgr.stashes["active"] = simgr.active[:1]
         if events:
-            simgr.am_event(src='filter_actives', filtered=stashed)
+            simgr.am_event(src="filter_actives", filtered=stashed)
         return True
 
-
     @staticmethod
     def _get_checked_items(qlist: QTreeWidget):
         items = []
@@ -327,15 +346,17 @@ class QSimulationManagers(QFrame):
                         items.append(sub_item)
         return items
 
-    def _import_to_list(self,qlist: QTreeWidget):
-        text, ok = QInputDialog.getMultiLineText(self,"Input Address List","Address in hex (one address each line):","")
+    def _import_to_list(self, qlist: QTreeWidget):
+        text, ok = QInputDialog.getMultiLineText(
+            self, "Input Address List", "Address in hex (one address each line):", ""
+        )
         if not ok:
             return
         for line in text.splitlines(keepends=False):
             try:
                 addr = int(line, 16)
                 self.add_address_to_list(qlist, addr)
-            except ValueError as e: #pylint: disable=unused-variable
+            except ValueError as e:  # pylint: disable=unused-variable
                 pass
 
     @staticmethod
